@@ -81,6 +81,7 @@ class AEA(Agent, WithLogger):
             DecisionMakerHandler
         ] = DefaultDecisionMakerHandler,
         skill_exception_policy: ExceptionPolicyEnum = ExceptionPolicyEnum.propagate,
+        connection_exception_policy: ExceptionPolicyEnum = ExceptionPolicyEnum.propagate,
         loop_mode: Optional[str] = None,
         runtime_mode: Optional[str] = None,
         default_connection: Optional[PublicId] = None,
@@ -111,6 +112,10 @@ class AEA(Agent, WithLogger):
 
         :return: None
         """
+
+        self._skills_exception_policy = skill_exception_policy
+        self._connection_exception_policy = connection_exception_policy
+
         super().__init__(
             identity=identity,
             connections=[],
@@ -119,6 +124,7 @@ class AEA(Agent, WithLogger):
             loop_mode=loop_mode,
             runtime_mode=runtime_mode,
         )
+
         aea_logger = AgentLoggerAdapter(
             logger=logging.getLogger(__name__), agent_name=identity.name
         )
@@ -140,6 +146,7 @@ class AEA(Agent, WithLogger):
             default_connection,
             default_routing if default_routing is not None else {},
             search_service_address,
+            decision_maker_handler.self_address,
             **kwargs,
         )
         self._execution_timeout = execution_timeout
@@ -149,8 +156,6 @@ class AEA(Agent, WithLogger):
             self.resources, self.runtime.decision_maker.message_out_queue
         )
 
-        self._skills_exception_policy = skill_exception_policy
-
         self._setup_loggers()
 
     @property
