@@ -287,6 +287,7 @@ class AEABuilder:
         DecisionMakerHandler
     ] = DefaultDecisionMakerHandler
     DEFAULT_SKILL_EXCEPTION_POLICY = ExceptionPolicyEnum.propagate
+    DEFAULT_CONNECTION_EXCEPTION_POLICY = ExceptionPolicyEnum.propagate
     DEFAULT_LOOP_MODE = "async"
     DEFAULT_RUNTIME_MODE = "threaded"
     DEFAULT_SEARCH_SERVICE_ADDRESS = "fetchai/soef:*"
@@ -350,6 +351,7 @@ class AEABuilder:
         self._max_reactions: Optional[int] = None
         self._decision_maker_handler_class: Optional[Type[DecisionMakerHandler]] = None
         self._skill_exception_policy: Optional[ExceptionPolicyEnum] = None
+        self._connection_exception_policy: Optional[ExceptionPolicyEnum] = None
         self._default_routing: Dict[PublicId, PublicId] = {}
         self._loop_mode: Optional[str] = None
         self._runtime_mode: Optional[str] = None
@@ -440,6 +442,19 @@ class AEABuilder:
         self._skill_exception_policy = skill_exception_policy
         return self
 
+    def set_connection_exception_policy(
+        self, connection_exception_policy: Optional[ExceptionPolicyEnum]
+    ) -> "AEABuilder":  # pragma: nocover
+        """
+        Set skill exception policy.
+
+        :param skill_exception_policy: the policy
+
+        :return: self
+        """
+        self._connection_exception_policy = connection_exception_policy
+        return self
+
     def set_default_routing(
         self, default_routing: Dict[PublicId, PublicId]
     ) -> "AEABuilder":
@@ -877,6 +892,7 @@ class AEABuilder:
             max_reactions=self._get_max_reactions(),
             decision_maker_handler_class=self._get_decision_maker_handler_class(),
             skill_exception_policy=self._get_skill_exception_policy(),
+            connection_exception_policy=self._get_connection_exception_policy(),
             default_routing=self._get_default_routing(),
             default_connection=self._get_default_connection(),
             loop_mode=self._get_loop_mode(),
@@ -947,6 +963,18 @@ class AEABuilder:
             else self.DEFAULT_SKILL_EXCEPTION_POLICY
         )
 
+    def _get_connection_exception_policy(self) -> ExceptionPolicyEnum:
+        """
+        Return the skill exception policy.
+
+        :return: the skill exception policy.
+        """
+        return (
+            self._connection_exception_policy
+            if self._connection_exception_policy is not None
+            else self.DEFAULT_CONNECTION_EXCEPTION_POLICY
+        )
+
     def _get_default_routing(self) -> Dict[PublicId, PublicId]:
         """
         Return the default routing.
@@ -1139,6 +1167,10 @@ class AEABuilder:
             self.set_skill_exception_policy(
                 ExceptionPolicyEnum(agent_configuration.skill_exception_policy)
             )
+        if agent_configuration.connection_exception_policy is not None:
+            self.set_connection_exception_policy(
+                ExceptionPolicyEnum(agent_configuration.connection_exception_policy)
+            )
         self.set_default_routing(agent_configuration.default_routing)
         self.set_loop_mode(agent_configuration.loop_mode)
         self.set_runtime_mode(agent_configuration.runtime_mode)
