@@ -40,8 +40,8 @@ from aea.cli.utils.package_utils import (
 from aea.configurations.base import PublicId
 from aea.configurations.constants import (
     DEFAULT_CONNECTION,
-    DEFAULT_PROTOCOL,
     DEFAULT_SKILL,
+    LOCAL_PROTOCOLS,
 )
 
 
@@ -116,7 +116,7 @@ def add_item(ctx: Context, item_type: str, item_public_id: PublicId) -> None:
     is_local = ctx.config.get("is_local")
 
     ctx.clean_paths.append(dest_path)
-    if item_public_id in [DEFAULT_CONNECTION, DEFAULT_PROTOCOL, DEFAULT_SKILL]:
+    if item_public_id in [DEFAULT_CONNECTION, *LOCAL_PROTOCOLS, DEFAULT_SKILL]:
         source_path = find_item_in_distribution(ctx, item_type, item_public_id)
         package_path = copy_package_directory(source_path, dest_path)
     elif is_local:
@@ -131,8 +131,8 @@ def add_item(ctx: Context, item_type: str, item_public_id: PublicId) -> None:
     if not is_fingerprint_correct(package_path, item_config):  # pragma: no cover
         raise click.ClickException("Failed to add an item with incorrect fingerprint.")
 
-    register_item(ctx, item_type, item_public_id)
     _add_item_deps(ctx, item_type, item_config)
+    register_item(ctx, item_type, item_public_id)
 
 
 def _add_item_deps(ctx: Context, item_type: str, item_config) -> None:
@@ -156,3 +156,8 @@ def _add_item_deps(ctx: Context, item_type: str, item_config) -> None:
         for contract_public_id in item_config.contracts:
             if contract_public_id not in ctx.agent_config.contracts:
                 add_item(ctx, "contract", contract_public_id)
+
+        # add missing skill
+        for skill_public_id in item_config.skills:
+            if skill_public_id not in ctx.agent_config.skills:
+                add_item(ctx, "skill", skill_public_id)
