@@ -35,7 +35,7 @@ from aea.configurations.base import DEFAULT_AEA_CONFIG_FILE, PublicId
 @click.group()
 @click.pass_context
 @check_aea_project
-def remove(click_context):
+def remove(click_context):  # pylint: disable=unused-argument
     """Remove a resource from the agent."""
 
 
@@ -128,17 +128,16 @@ def remove_item(ctx: Context, item_type: str, item_id: PublicId) -> None:
             raise click.ClickException(
                 "{} {} not found. Aborting.".format(item_type.title(), item_name)
             )
-        elif (
+        if (
             item_folder.exists() and not ctx.agent_config.author == item_id.author
         ):  # pragma: no cover
             raise click.ClickException(
                 "{} {} author is different from {} agent author. "
                 "Please fix the author field.".format(item_name, item_type, agent_name)
             )
-        else:
-            logger.debug(
-                "Removing local {} {}.".format(item_type, item_name)
-            )  # pragma: no cover
+        logger.debug(
+            "Removing local {} {}.".format(item_type, item_name)
+        )  # pragma: no cover
 
     try:
         shutil.rmtree(item_folder)
