@@ -18,11 +18,13 @@
 # ------------------------------------------------------------------------------
 
 """This module contains definitions of agent components."""
+import importlib.util
 import logging
+import sys
 import types
 from abc import ABC
 from pathlib import Path
-from typing import Dict, Optional
+from typing import Optional
 
 from aea.configurations.base import (
     ComponentConfiguration,
@@ -30,6 +32,7 @@ from aea.configurations.base import (
     ComponentType,
     PublicId,
 )
+from aea.exceptions import AEAEnforceError
 from aea.helpers.logging import WithLogger
 
 logger = logging.getLogger(__name__)
@@ -42,7 +45,7 @@ class Component(ABC, WithLogger):
         self,
         configuration: Optional[ComponentConfiguration] = None,
         is_vendor: bool = False,
-        **kwargs
+        **kwargs,
     ):
         """
         Initialize a package.
@@ -55,10 +58,6 @@ class Component(ABC, WithLogger):
         self._directory = None  # type: Optional[Path]
         self._is_vendor = is_vendor
 
-        # mapping from import path to module object
-        # the keys are dotted paths of Python modules.
-        self.importpath_to_module = {}  # type: Dict[str, types.ModuleType]
-
     @property
     def component_type(self) -> ComponentType:
         """Get the component type."""
@@ -87,19 +86,59 @@ class Component(ABC, WithLogger):
     @property
     def configuration(self) -> ComponentConfiguration:
         """Get the component configuration."""
-        assert (
-            self._configuration is not None
-        ), "The component is not associated with a configuration."
+        if self._configuration is None:  # pragma: nocover
+            raise ValueError("The component is not associated with a configuration.")
         return self._configuration
 
     @property
     def directory(self) -> Path:
         """Get the directory. Raise error if it has not been set yet."""
-        assert self._directory is not None, "Directory not set yet."
+        if self._directory is None:
+            raise ValueError("Directory not set yet.")
         return self._directory
 
     @directory.setter
     def directory(self, path: Path) -> None:
         """Set the directory. Raise error if already set."""
-        assert self._directory is None, "Directory already set."
+        if self._directory is not None:  # pragma: nocover
+            raise ValueError("Directory already set.")
         self._directory = path
+
+
+def load_aea_package(configuration: ComponentConfiguration) -> None:
+    """
+    Load the AEA package.
+
+    It adds all the __init__.py modules into `sys.modules`.
+
+    :param configuration: the configuration object.
+    :return: None
+    """
+    dir_ = configuration.directory
+    if dir_ is None:  # pragma: nocover
+        raise AEAEnforceError("configuration directory does not exists.")
+
+    # patch sys.modules with dummy modules
+    prefix_root = "packages"
+    prefix_author = prefix_root + f".{configuration.author}"
+    prefix_pkg_type = prefix_author + f".{configuration.component_type.to_plural()}"
+    prefix_pkg = prefix_pkg_type + f".{configuration.name}"
+    sys.modules[prefix_root] = types.ModuleType(prefix_root)
+    sys.modules[prefix_author] = types.ModuleType(prefix_author)
+    sys.modules[prefix_pkg_type] = types.ModuleType(prefix_pkg_type)
+
+    for subpackage_init_file in dir_.rglob("__init__.py"):
+        parent_dir = subpackage_init_file.parent
+        relative_parent_dir = parent_dir.relative_to(dir_)
+        if relative_parent_dir == Path("."):
+            # this handles the case when 'subpackage_init_file'
+            # is path/to/package/__init__.py
+            import_path = prefix_pkg
+        else:
+            import_path = prefix_pkg + "." + ".".join(relative_parent_dir.parts)
+
+        spec = importlib.util.spec_from_file_location(import_path, subpackage_init_file)
+        module = importlib.util.module_from_spec(spec)
+        sys.modules[import_path] = module
+        logger.debug(f"loading {import_path}: {module}")
+        spec.loader.exec_module(module)  # type: ignore
