@@ -20,7 +20,6 @@
 """This module contains the base message and serialization definition."""
 import importlib
 import inspect
-import json
 import logging
 import re
 from abc import ABC, abstractmethod
@@ -31,14 +30,14 @@ from typing import Any, Dict, Optional, Tuple, Type, cast
 
 from google.protobuf.struct_pb2 import Struct
 
-from aea.components.base import Component
+from aea.components.base import Component, load_aea_package
 from aea.configurations.base import (
-    ComponentConfiguration,
     ComponentType,
     ProtocolConfig,
     PublicId,
 )
-from aea.helpers.base import load_aea_package
+from aea.configurations.loader import load_component_configuration
+from aea.exceptions import enforce
 
 logger = logging.getLogger(__name__)
 
@@ -67,10 +66,8 @@ class Message:
         """
         self._to = None  # type: Optional[Address]
         self._sender = None  # type: Optional[Address]
-        self._counterparty = None  # type: Optional[Address]
         self._body = copy(body) if body else {}  # type: Dict[str, Any]
         self._body.update(kwargs)
-        self._is_incoming = False
         try:
             self._is_consistent()
         except Exception as e:  # pylint: disable=broad-except
@@ -88,13 +85,14 @@ class Message:
 
         :return the address
         """
-        assert self._sender is not None, "Sender must not be None."
+        if self._sender is None:
+            raise ValueError("Message's 'Sender' field must be set.")  # pragma: nocover
         return self._sender
 
     @sender.setter
     def sender(self, sender: Address) -> None:
         """Set the sender of the message."""
-        # assert self._sender is None, "Sender already set."
+        enforce(self._sender is None, "Sender already set.")
         self._sender = sender
 
     @property
@@ -105,49 +103,16 @@ class Message:
     @property
     def to(self) -> Address:
         """Get address of receiver."""
-        assert self._to is not None, "To must not be None."
+        if self._to is None:
+            raise ValueError("Message's 'To' field must be set.")
         return self._to
 
     @to.setter
     def to(self, to: Address) -> None:
         """Set address of receiver."""
-        assert self._to is None, "To already set."
+        enforce(self._to is None, "To already set.")
         self._to = to
 
-    @property
-    def has_counterparty(self) -> bool:
-        """Check if the counterparty is set."""
-        return self._counterparty is not None
-
-    @property
-    def counterparty(self) -> Address:
-        """
-        Get the counterparty of the message in Address form.
-
-        :return the address
-        """
-        assert self._counterparty is not None, "Counterparty must not be None."
-        return self._counterparty
-
-    @counterparty.setter
-    def counterparty(self, counterparty: Address) -> None:
-        """Set the counterparty of the message."""
-        self._counterparty = counterparty
-
-    @property
-    def is_incoming(self) -> bool:
-        """
-        Get the is_incoming value of the message.
-
-        :return whether the message is incoming or is out going
-        """
-        return self._is_incoming
-
-    @is_incoming.setter
-    def is_incoming(self, is_incoming: bool) -> None:
-        """Set the is_incoming of the message."""
-        self._is_incoming = is_incoming
-
     @property
     def body(self) -> Dict:
         """
@@ -170,25 +135,29 @@ class Message:
     @property
     def dialogue_reference(self) -> Tuple[str, str]:
         """Get the dialogue_reference of the message."""
-        assert self.is_set("dialogue_reference"), "dialogue_reference is not set."
+        if not self.is_set("dialogue_reference"):
+            raise ValueError("dialogue_reference is not set.")  # pragma: nocover
         return cast(Tuple[str, str], self.get("dialogue_reference"))
 
     @property
     def message_id(self) -> int:
         """Get the message_id of the message."""
-        assert self.is_set("message_id"), "message_id is not set."
+        if not self.is_set("message_id"):
+            raise ValueError("message_id is not set.")  # pragma: nocover
         return cast(int, self.get("message_id"))
 
     @property
     def performative(self) -> "Performative":
         """Get the performative of the message."""
-        assert self.is_set("performative"), "performative is not set."
+        if not self.is_set("performative"):
+            raise ValueError("performative is not set.")  # pragma: nocover
         return cast(Message.Performative, self.get("performative"))
 
     @property
     def target(self) -> int:
         """Get the target of the message."""
-        assert self.is_set("target"), "target is not set."
+        if not self.is_set("target"):
+            raise ValueError("target is not set.")  # pragma: nocover
         return cast(int, self.get("target"))
 
     def set(self, key: str, value: Any) -> None:
@@ -205,10 +174,6 @@ class Message:
         """Get value for key."""
         return self._body.get(key, None)
 
-    def unset(self, key: str) -> None:
-        """Unset valye for key."""
-        self._body.pop(key, None)
-
     def is_set(self, key: str) -> bool:
         """Check value is set for key."""
         return key in self._body
@@ -221,15 +186,20 @@ class Message:
         """Compare with another object."""
         return (
             isinstance(other, Message)
+            and self._sender == other._sender
+            and self._to == other._to
+            # and self.dialogue_reference == other.dialogue_reference  # noqa: E800
+            # and self.message_id == other.message_id  # noqa: E800
+            # and self.target == other.target  # noqa: E800
+            # and self.performative == other.performative  # noqa: E800
             and self.body == other.body
-            and self._counterparty == other._counterparty
         )
 
     def __str__(self):
         """Get the string representation of the message."""
         return (
-            "Message("
-            + " ".join(
+            "Message(sender={},to={},".format(self._sender, self._to)
+            + ",".join(
                 map(
                     lambda key_value: str(key_value[0]) + "=" + str(key_value[1]),
                     self.body.items(),
@@ -301,36 +271,6 @@ class ProtobufSerializer(Serializer):
         return msg
 
 
-class JSONSerializer(Serializer):
-    """
-    Default serialization in JSON for the Message object.
-
-    It assumes that the Message contains a JSON-serializable body.
-    """
-
-    @staticmethod
-    def encode(msg: Message) -> bytes:
-        """
-        Encode a message into bytes using JSON format.
-
-        :param msg: the message to be encoded.
-        :return: the serialized message.
-        """
-        bytes_msg = json.dumps(msg.body).encode("utf-8")
-        return bytes_msg
-
-    @staticmethod
-    def decode(obj: bytes) -> Message:
-        """
-        Decode bytes into a message using JSON.
-
-        :param obj: the serialized message.
-        :return: the decoded message.
-        """
-        json_msg = json.loads(obj.decode("utf-8"))
-        return Message(json_msg)
-
-
 class Protocol(Component):
     """
     This class implements a specifications for a protocol.
@@ -366,7 +306,7 @@ class Protocol(Component):
         """
         configuration = cast(
             ProtocolConfig,
-            ComponentConfiguration.load(ComponentType.PROTOCOL, Path(directory)),
+            load_component_configuration(ComponentType.PROTOCOL, Path(directory)),
         )
         configuration.directory = Path(directory)
         return Protocol.from_config(configuration, **kwargs)
@@ -379,9 +319,8 @@ class Protocol(Component):
         :param configuration: the protocol configuration.
         :return: the protocol object.
         """
-        assert (
-            configuration.directory is not None
-        ), "Configuration must be associated with a directory."
+        if configuration.directory is None:  # pragma: nocover
+            raise ValueError("Configuration must be associated with a directory.")
         load_aea_package(configuration)
         class_module = importlib.import_module(
             configuration.prefix_import_path + ".message"
@@ -395,7 +334,7 @@ class Protocol(Component):
                 lambda x: re.match("{}Message".format(name_camel_case), x[0]), classes
             )
         )
-        assert len(message_classes) == 1, "Not exactly one message class detected."
+        enforce(len(message_classes) == 1, "Not exactly one message class detected.")
         message_class = message_classes[0][1]
         class_module = importlib.import_module(
             configuration.prefix_import_path + ".serialization"
@@ -407,9 +346,9 @@ class Protocol(Component):
                 classes,
             )
         )
-        assert (
-            len(serializer_classes) == 1
-        ), "Not exactly one serializer class detected."
+        enforce(
+            len(serializer_classes) == 1, "Not exactly one serializer class detected."
+        )
         serialize_class = serializer_classes[0][1]
         message_class.serializer = serialize_class
 
