@@ -235,7 +235,7 @@ class ProtocolGenerator:
 
         :return: the performatives Enum string
         """
-        enum_str = self.indent + "class Performative(Enum):\n"
+        enum_str = self.indent + "class Performative(Message.Performative):\n"
         self._change_indent(1)
         enum_str += self.indent + '"""Performatives for the {} protocol."""\n\n'.format(
             self.protocol_specification.name
@@ -307,13 +307,13 @@ class ProtocolGenerator:
                     unique_standard_types_set.add(typing_content_type)
             unique_standard_types_list = sorted(unique_standard_types_set)
             check_str += self.indent
-            check_str += "assert "
+            check_str += "enforce("
             for unique_type in unique_standard_types_list:
                 check_str += "type({}) == {} or ".format(
                     content_variable, self._to_custom_custom(unique_type)
                 )
             check_str = check_str[:-4]
-            check_str += ", \"Invalid type for content '{}'. Expected either of '{}'. Found '{{}}'.\".format(type({}))\n".format(
+            check_str += ", \"Invalid type for content '{}'. Expected either of '{}'. Found '{{}}'.\".format(type({})))\n".format(
                 content_name,
                 [
                     unique_standard_type
@@ -326,7 +326,7 @@ class ProtocolGenerator:
                     content_variable
                 )
                 self._change_indent(1)
-                check_str += self.indent + "assert (\n"
+                check_str += self.indent + "enforce(\n"
                 self._change_indent(1)
                 frozen_set_element_types_set = set()
                 for element_type in element_types:
@@ -349,7 +349,7 @@ class ProtocolGenerator:
                 if len(frozen_set_element_types) == 1:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for elements of content '{}'. Expected ".format(
+                        + ", \"Invalid type for elements of content '{}'. Expected ".format(
                             content_name
                         )
                     )
@@ -357,11 +357,11 @@ class ProtocolGenerator:
                         check_str += "'{}'".format(
                             self._to_custom_custom(frozen_set_element_type)
                         )
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 else:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for frozenset elements in content '{}'. Expected either ".format(
+                        + ", \"Invalid type for frozenset elements in content '{}'. Expected either ".format(
                             content_name
                         )
                     )
@@ -370,14 +370,14 @@ class ProtocolGenerator:
                             self._to_custom_custom(frozen_set_element_type)
                         )
                     check_str = check_str[:-4]
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 self._change_indent(-1)
             if "tuple" in unique_standard_types_list:
                 check_str += self.indent + "if type({}) == tuple:\n".format(
                     content_variable
                 )
                 self._change_indent(1)
-                check_str += self.indent + "assert (\n"
+                check_str += self.indent + "enforce(\n"
                 self._change_indent(1)
                 tuple_element_types_set = set()
                 for element_type in element_types:
@@ -399,7 +399,7 @@ class ProtocolGenerator:
                 if len(tuple_element_types) == 1:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for tuple elements in content '{}'. Expected ".format(
+                        + ", \"Invalid type for tuple elements in content '{}'. Expected ".format(
                             content_name
                         )
                     )
@@ -407,11 +407,11 @@ class ProtocolGenerator:
                         check_str += "'{}'".format(
                             self._to_custom_custom(tuple_element_type)
                         )
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 else:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for tuple elements in content '{}'. Expected either ".format(
+                        + ", \"Invalid type for tuple elements in content '{}'. Expected either ".format(
                             content_name
                         )
                     )
@@ -420,7 +420,7 @@ class ProtocolGenerator:
                             self._to_custom_custom(tuple_element_type)
                         )
                     check_str = check_str[:-4]
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 self._change_indent(-1)
             if "dict" in unique_standard_types_list:
                 check_str += self.indent + "if type({}) == dict:\n".format(
@@ -434,7 +434,7 @@ class ProtocolGenerator:
                     )
                 )
                 self._change_indent(1)
-                check_str += self.indent + "assert (\n"
+                check_str += self.indent + "enforce(\n"
                 self._change_indent(1)
                 dict_key_value_types = dict()
                 for element_type in element_types:
@@ -459,17 +459,17 @@ class ProtocolGenerator:
                 if len(dict_key_value_types) == 1:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for dictionary key, value in content '{}'. Expected ".format(
+                        + ", \"Invalid type for dictionary key, value in content '{}'. Expected ".format(
                             content_name
                         )
                     )
                     for key in sorted(dict_key_value_types.keys()):
                         check_str += "'{}', '{}'".format(key, dict_key_value_types[key])
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 else:
                     check_str += (
                         self.indent
-                        + "), \"Invalid type for dictionary key, value in content '{}'. Expected ".format(
+                        + ", \"Invalid type for dictionary key, value in content '{}'. Expected ".format(
                             content_name
                         )
                     )
@@ -478,18 +478,18 @@ class ProtocolGenerator:
                             key, dict_key_value_types[key]
                         )
                     check_str = check_str[:-4]
-                    check_str += '."\n'
+                    check_str += '.")\n'
                 self._change_indent(-2)
         elif content_type.startswith("FrozenSet["):
             # check the type
             check_str += (
                 self.indent
-                + "assert type({}) == frozenset, \"Invalid type for content '{}'. Expected 'frozenset'. Found '{{}}'.\".format(type({}))\n".format(
+                + "enforce(type({}) == frozenset, \"Invalid type for content '{}'. Expected 'frozenset'. Found '{{}}'.\".format(type({})))\n".format(
                     content_variable, content_name, content_variable
                 )
             )
             element_type = _get_sub_types_of_compositional_types(content_type)[0]
-            check_str += self.indent + "assert all(\n"
+            check_str += self.indent + "enforce(all(\n"
             self._change_indent(1)
             check_str += self.indent + "type(element) == {} for element in {}\n".format(
                 self._to_custom_custom(element_type), content_variable
@@ -497,7 +497,7 @@ class ProtocolGenerator:
             self._change_indent(-1)
             check_str += (
                 self.indent
-                + "), \"Invalid type for frozenset elements in content '{}'. Expected '{}'.\"\n".format(
+                + "), \"Invalid type for frozenset elements in content '{}'. Expected '{}'.\")\n".format(
                     content_name, element_type
                 )
             )
@@ -505,12 +505,12 @@ class ProtocolGenerator:
             # check the type
             check_str += (
                 self.indent
-                + "assert type({}) == tuple, \"Invalid type for content '{}'. Expected 'tuple'. Found '{{}}'.\".format(type({}))\n".format(
+                + "enforce(type({}) == tuple, \"Invalid type for content '{}'. Expected 'tuple'. Found '{{}}'.\".format(type({})))\n".format(
                     content_variable, content_name, content_variable
                 )
             )
             element_type = _get_sub_types_of_compositional_types(content_type)[0]
-            check_str += self.indent + "assert all(\n"
+            check_str += self.indent + "enforce(all(\n"
             self._change_indent(1)
             check_str += self.indent + "type(element) == {} for element in {}\n".format(
                 self._to_custom_custom(element_type), content_variable
@@ -518,7 +518,7 @@ class ProtocolGenerator:
             self._change_indent(-1)
             check_str += (
                 self.indent
-                + "), \"Invalid type for tuple elements in content '{}'. Expected '{}'.\"\n".format(
+                + "), \"Invalid type for tuple elements in content '{}'. Expected '{}'.\")\n".format(
                     content_name, element_type
                 )
             )
@@ -526,7 +526,7 @@ class ProtocolGenerator:
             # check the type
             check_str += (
                 self.indent
-                + "assert type({}) == dict, \"Invalid type for content '{}'. Expected 'dict'. Found '{{}}'.\".format(type({}))\n".format(
+                + "enforce(type({}) == dict, \"Invalid type for content '{}'. Expected 'dict'. Found '{{}}'.\".format(type({})))\n".format(
                     content_variable, content_name, content_variable
                 )
             )
@@ -540,7 +540,7 @@ class ProtocolGenerator:
                 )
             )
             self._change_indent(1)
-            check_str += self.indent + "assert (\n"
+            check_str += self.indent + "enforce(\n"
             self._change_indent(1)
             check_str += self.indent + "type(key_of_{}) == {}\n".format(
                 content_name, self._to_custom_custom(element_type_1)
@@ -548,12 +548,12 @@ class ProtocolGenerator:
             self._change_indent(-1)
             check_str += (
                 self.indent
-                + "), \"Invalid type for dictionary keys in content '{}'. Expected '{}'. Found '{{}}'.\".format(type(key_of_{}))\n".format(
+                + ", \"Invalid type for dictionary keys in content '{}'. Expected '{}'. Found '{{}}'.\".format(type(key_of_{})))\n".format(
                     content_name, element_type_1, content_name
                 )
             )
 
-            check_str += self.indent + "assert (\n"
+            check_str += self.indent + "enforce(\n"
             self._change_indent(1)
             check_str += self.indent + "type(value_of_{}) == {}\n".format(
                 content_name, self._to_custom_custom(element_type_2)
@@ -561,7 +561,7 @@ class ProtocolGenerator:
             self._change_indent(-1)
             check_str += (
                 self.indent
-                + "), \"Invalid type for dictionary values in content '{}'. Expected '{}'. Found '{{}}'.\".format(type(value_of_{}))\n".format(
+                + ", \"Invalid type for dictionary values in content '{}'. Expected '{}'. Found '{{}}'.\".format(type(value_of_{})))\n".format(
                     content_name, element_type_2, content_name
                 )
             )
@@ -569,7 +569,7 @@ class ProtocolGenerator:
         else:
             check_str += (
                 self.indent
-                + "assert type({}) == {}, \"Invalid type for content '{}'. Expected '{}'. Found '{{}}'.\".format(type({}))\n".format(
+                + "enforce(type({}) == {}, \"Invalid type for content '{}'. Expected '{}'. Found '{{}}'.\".format(type({})))\n".format(
                     content_variable,
                     self._to_custom_custom(content_type),
                     content_name,
@@ -602,9 +602,9 @@ class ProtocolGenerator:
 
         # Imports
         cls_str += self.indent + "import logging\n"
-        cls_str += self.indent + "from enum import Enum\n"
         cls_str += self._import_from_typing_module() + "\n\n"
         cls_str += self.indent + "from aea.configurations.base import ProtocolId\n"
+        cls_str += self.indent + "from aea.exceptions import AEAEnforceError, enforce\n"
         cls_str += MESSAGE_IMPORT + "\n"
         if self._import_from_custom_types_module() != "":
             cls_str += "\n" + self._import_from_custom_types_module() + "\n"
@@ -664,6 +664,9 @@ class ProtocolGenerator:
         cls_str += self.indent + ":param target: the message target.\n"
         cls_str += self.indent + ":param performative: the message performative.\n"
         cls_str += self.indent + '"""\n'
+        cls_str += self.indent + "self._performatives = {}\n".format(
+            self._performatives_str()
+        )
         cls_str += self.indent + "super().__init__(\n"
         self._change_indent(1)
         cls_str += self.indent + "dialogue_reference=dialogue_reference,\n"
@@ -678,9 +681,7 @@ class ProtocolGenerator:
         cls_str += self.indent + "**kwargs,\n"
         self._change_indent(-1)
         cls_str += self.indent + ")\n"
-        cls_str += self.indent + "self._performatives = {}\n".format(
-            self._performatives_str()
-        )
+
         self._change_indent(-1)
 
         # Instance properties
@@ -696,7 +697,7 @@ class ProtocolGenerator:
         cls_str += self.indent + '"""Get the dialogue_reference of the message."""\n'
         cls_str += (
             self.indent
-            + 'assert self.is_set("dialogue_reference"), "dialogue_reference is not set."\n'
+            + 'enforce(self.is_set("dialogue_reference"), "dialogue_reference is not set.")\n'
         )
         cls_str += (
             self.indent
@@ -708,7 +709,8 @@ class ProtocolGenerator:
         self._change_indent(1)
         cls_str += self.indent + '"""Get the message_id of the message."""\n'
         cls_str += (
-            self.indent + 'assert self.is_set("message_id"), "message_id is not set."\n'
+            self.indent
+            + 'enforce(self.is_set("message_id"), "message_id is not set.")\n'
         )
         cls_str += self.indent + 'return cast(int, self.get("message_id"))\n\n'
         self._change_indent(-1)
@@ -721,7 +723,7 @@ class ProtocolGenerator:
         cls_str += self.indent + '"""Get the performative of the message."""\n'
         cls_str += (
             self.indent
-            + 'assert self.is_set("performative"), "performative is not set."\n'
+            + 'enforce(self.is_set("performative"), "performative is not set.")\n'
         )
         cls_str += (
             self.indent
@@ -734,7 +736,9 @@ class ProtocolGenerator:
         cls_str += self.indent + "def target(self) -> int:\n"
         self._change_indent(1)
         cls_str += self.indent + '"""Get the target of the message."""\n'
-        cls_str += self.indent + 'assert self.is_set("target"), "target is not set."\n'
+        cls_str += (
+            self.indent + 'enforce(self.is_set("target"), "target is not set.")\n'
+        )
         cls_str += self.indent + 'return cast(int, self.get("target"))\n\n'
         self._change_indent(-1)
 
@@ -754,7 +758,7 @@ class ProtocolGenerator:
             if not content_type.startswith("Optional"):
                 cls_str += (
                     self.indent
-                    + 'assert self.is_set("{}"), "\'{}\' content is not set."\n'.format(
+                    + 'enforce(self.is_set("{}"), "\'{}\' content is not set.")\n'.format(
                         content_name, content_name
                     )
                 )
@@ -776,35 +780,35 @@ class ProtocolGenerator:
         self._change_indent(1)
         cls_str += (
             self.indent
-            + "assert type(self.dialogue_reference) == tuple, \"Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.\""
-            ".format(type(self.dialogue_reference))\n"
+            + "enforce(type(self.dialogue_reference) == tuple, \"Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.\""
+            ".format(type(self.dialogue_reference)))\n"
         )
         cls_str += (
             self.indent
-            + "assert type(self.dialogue_reference[0]) == str, \"Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.\""
-            ".format(type(self.dialogue_reference[0]))\n"
+            + "enforce(type(self.dialogue_reference[0]) == str, \"Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.\""
+            ".format(type(self.dialogue_reference[0])))\n"
         )
         cls_str += (
             self.indent
-            + "assert type(self.dialogue_reference[1]) == str, \"Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.\""
-            ".format(type(self.dialogue_reference[1]))\n"
+            + "enforce(type(self.dialogue_reference[1]) == str, \"Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.\""
+            ".format(type(self.dialogue_reference[1])))\n"
         )
         cls_str += (
             self.indent
-            + "assert type(self.message_id) == int, \"Invalid type for 'message_id'. Expected 'int'. Found '{}'.\""
-            ".format(type(self.message_id))\n"
+            + "enforce(type(self.message_id) == int, \"Invalid type for 'message_id'. Expected 'int'. Found '{}'.\""
+            ".format(type(self.message_id)))\n"
         )
         cls_str += (
             self.indent
-            + "assert type(self.target) == int, \"Invalid type for 'target'. Expected 'int'. Found '{}'.\""
-            ".format(type(self.target))\n\n"
+            + "enforce(type(self.target) == int, \"Invalid type for 'target'. Expected 'int'. Found '{}'.\""
+            ".format(type(self.target)))\n\n"
         )
 
         cls_str += self.indent + "# Light Protocol Rule 2\n"
         cls_str += self.indent + "# Check correct performative\n"
         cls_str += (
             self.indent
-            + "assert type(self.performative) == {}Message.Performative".format(
+            + "enforce(type(self.performative) == {}Message.Performative".format(
                 self.protocol_specification_in_camel_case
             )
         )
@@ -812,7 +816,7 @@ class ProtocolGenerator:
             ", \"Invalid 'performative'. Expected either of '{}'. Found '{}'.\".format("
         )
         cls_str += "self.valid_performatives, self.performative"
-        cls_str += ")\n\n"
+        cls_str += "))\n\n"
 
         cls_str += self.indent + "# Check correct contents\n"
         cls_str += (
@@ -845,9 +849,9 @@ class ProtocolGenerator:
         cls_str += "\n"
         cls_str += self.indent + "# Check correct content count\n"
         cls_str += (
-            self.indent + "assert expected_nb_of_contents == actual_nb_of_contents, "
+            self.indent + "enforce(expected_nb_of_contents == actual_nb_of_contents, "
             '"Incorrect number of contents. Expected {}. Found {}"'
-            ".format(expected_nb_of_contents, actual_nb_of_contents)\n\n"
+            ".format(expected_nb_of_contents, actual_nb_of_contents))\n\n"
         )
 
         cls_str += self.indent + "# Light Protocol Rule 3\n"
@@ -855,18 +859,20 @@ class ProtocolGenerator:
         self._change_indent(1)
         cls_str += (
             self.indent
-            + "assert self.target == 0, \"Invalid 'target'. Expected 0 (because 'message_id' is 1). Found {}.\".format(self.target)\n"
+            + "enforce(self.target == 0, \"Invalid 'target'. Expected 0 (because 'message_id' is 1). Found {}.\".format(self.target))\n"
         )
         self._change_indent(-1)
         cls_str += self.indent + "else:\n"
         self._change_indent(1)
         cls_str += (
-            self.indent + "assert 0 < self.target < self.message_id, "
+            self.indent + "enforce(0 < self.target < self.message_id, "
             "\"Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.\""
-            ".format(self.message_id - 1, self.target,)\n"
+            ".format(self.message_id - 1, self.target,))\n"
         )
         self._change_indent(-2)
-        cls_str += self.indent + "except (AssertionError, ValueError, KeyError) as e:\n"
+        cls_str += (
+            self.indent + "except (AEAEnforceError, ValueError, KeyError) as e:\n"
+        )
         self._change_indent(1)
         cls_str += self.indent + "logger.error(str(e))\n"
         cls_str += self.indent + "return False\n\n"
@@ -983,14 +989,14 @@ class ProtocolGenerator:
         # Imports
         cls_str += self.indent + "from abc import ABC\n"
         cls_str += (
-            self.indent + "from typing import Dict, FrozenSet, Optional, cast\n\n"
+            self.indent + "from typing import Callable, FrozenSet, Type, cast\n\n"
         )
+        cls_str += self.indent + "from aea.common import Address\n"
+        cls_str += self.indent + "from aea.protocols.base import Message\n"
         cls_str += (
             self.indent
-            + "from aea.helpers.dialogue.base import Dialogue, DialogueLabel, Dialogues\n"
+            + "from aea.protocols.dialogue.base import Dialogue, DialogueLabel, Dialogues\n\n"
         )
-        cls_str += self.indent + "from aea.mail.base import Address\n"
-        cls_str += self.indent + "from aea.protocols.base import Message\n\n"
         cls_str += self.indent + "from {}.message import {}Message\n".format(
             self.dotted_path_to_protocol_package,
             self.protocol_specification_in_camel_case,
@@ -1047,8 +1053,12 @@ class ProtocolGenerator:
         self._change_indent(1)
         cls_str += self.indent + "self,\n"
         cls_str += self.indent + "dialogue_label: DialogueLabel,\n"
-        cls_str += self.indent + "agent_address: Optional[Address] = None,\n"
-        cls_str += self.indent + "role: Optional[Dialogue.Role] = None,\n"
+        cls_str += self.indent + "self_address: Address,\n"
+        cls_str += self.indent + "role: Dialogue.Role,\n"
+        cls_str += self.indent + "message_class: Type[{}Message] = {}Message,\n".format(
+            self.protocol_specification_in_camel_case,
+            self.protocol_specification_in_camel_case,
+        )
         self._change_indent(-1)
         cls_str += self.indent + ") -> None:\n"
         self._change_indent(1)
@@ -1059,7 +1069,7 @@ class ProtocolGenerator:
         )
         cls_str += (
             self.indent
-            + ":param agent_address: the address of the agent for whom this dialogue is maintained\n"
+            + ":param self_address: the address of the entity for whom this dialogue is maintained\n"
         )
         cls_str += (
             self.indent
@@ -1070,54 +1080,11 @@ class ProtocolGenerator:
         cls_str += self.indent + "Dialogue.__init__(\n"
         cls_str += self.indent + "self,\n"
         cls_str += self.indent + "dialogue_label=dialogue_label,\n"
-        cls_str += self.indent + "agent_address=agent_address,\n"
+        cls_str += self.indent + "message_class=message_class,\n"
+        cls_str += self.indent + "self_address=self_address,\n"
         cls_str += self.indent + "role=role,\n"
-        cls_str += self.indent + "rules=Dialogue.Rules(\n"
-        self._change_indent(1)
-        cls_str += (
-            self.indent
-            + "cast(FrozenSet[Message.Performative], self.INITIAL_PERFORMATIVES),\n"
-        )
-        cls_str += (
-            self.indent
-            + "cast(FrozenSet[Message.Performative], self.TERMINAL_PERFORMATIVES),\n"
-        )
-        cls_str += self.indent + "cast(\n"
-        self._change_indent(1)
-        cls_str += (
-            self.indent
-            + "Dict[Message.Performative, FrozenSet[Message.Performative]],\n"
-        )
-        cls_str += self.indent + "self.VALID_REPLIES,\n"
-        self._change_indent(-1)
-        cls_str += self.indent + "),\n"
-        self._change_indent(-1)
-        cls_str += self.indent + "),\n"
         cls_str += self.indent + ")\n"
-        self._change_indent(-1)
-
-        # is_valid method
-        cls_str += self.indent + "def is_valid(self, message: Message) -> bool:\n"
-        self._change_indent(1)
-        cls_str += self.indent + '"""\n'
-        cls_str += (
-            self.indent
-            + "Check whether 'message' is a valid next message in the dialogue.\n\n"
-        )
-        cls_str += (
-            self.indent
-            + "These rules capture specific constraints designed for dialogues which are instances of a concrete sub-class of this class.\n"
-        )
-        cls_str += (
-            self.indent
-            + "Override this method with your additional dialogue rules.\n\n"
-        )
-        cls_str += self.indent + ":param message: the message to be validated\n"
-        cls_str += self.indent + ":return: True if valid, False otherwise\n"
-        cls_str += self.indent + '"""\n'
-        cls_str += self.indent + "return True\n\n"
-        self._change_indent(-1)
-        self._change_indent(-1)
+        self._change_indent(-2)
 
         # dialogues class
         cls_str += self.indent + "class {}Dialogues(Dialogues, ABC):\n".format(
@@ -1141,55 +1108,48 @@ class ProtocolGenerator:
         cls_str += self.indent + "END_STATES = frozenset(\n"
         cls_str += self.indent + "{" + end_states_str + "}"
         cls_str += self.indent + ")\n\n"
-        cls_str += self.indent + "def __init__(self, agent_address: Address) -> None:\n"
+
+        cls_str += self.indent + "def __init__(\n"
+        self._change_indent(1)
+        cls_str += self.indent + "self,\n"
+        cls_str += self.indent + "self_address: Address,\n"
+        cls_str += (
+            self.indent
+            + "role_from_first_message: Callable[[Message, Address], Dialogue.Role],\n"
+        )
+        cls_str += (
+            self.indent
+            + "dialogue_class: Type[{}Dialogue] = {}Dialogue,\n".format(
+                self.protocol_specification_in_camel_case,
+                self.protocol_specification_in_camel_case,
+            )
+        )
+        self._change_indent(-1)
+        cls_str += self.indent + ") -> None:\n"
         self._change_indent(1)
         cls_str += self.indent + '"""\n'
         cls_str += self.indent + "Initialize dialogues.\n\n"
         cls_str += (
             self.indent
-            + ":param agent_address: the address of the agent for whom dialogues are maintained\n"
+            + ":param self_address: the address of the entity for whom dialogues are maintained\n"
         )
         cls_str += self.indent + ":return: None\n"
         cls_str += self.indent + '"""\n'
+        cls_str += self.indent + "Dialogues.__init__(\n"
+        self._change_indent(1)
+        cls_str += self.indent + "self,\n"
+        cls_str += self.indent + "self_address=self_address,\n"
         cls_str += (
             self.indent
-            + "Dialogues.__init__(self, agent_address=agent_address, end_states=cast(FrozenSet[Dialogue.EndState], self.END_STATES))\n"
+            + "end_states=cast(FrozenSet[Dialogue.EndState], self.END_STATES),\n"
         )
-        self._change_indent(-1)
-        cls_str += self.indent + "def create_dialogue(\n"
-        self._change_indent(1)
-        cls_str += (
-            self.indent + "self, dialogue_label: DialogueLabel, role: Dialogue.Role,\n"
-        )
-        self._change_indent(-1)
-        cls_str += self.indent + ") -> {}Dialogue:\n".format(
+        cls_str += self.indent + "message_class={}Message,\n".format(
             self.protocol_specification_in_camel_case
         )
-        self._change_indent(1)
-        cls_str += self.indent + '"""\n'
-        cls_str += self.indent + "Create an instance of {} dialogue.\n\n".format(
-            self.protocol_specification.name
-        )
-        cls_str += (
-            self.indent + ":param dialogue_label: the identifier of the dialogue\n"
-        )
-        cls_str += (
-            self.indent
-            + ":param role: the role of the agent this dialogue is maintained for\n\n"
-        )
-        cls_str += self.indent + ":return: the created dialogue\n"
-        cls_str += self.indent + '"""\n'
-        cls_str += self.indent + "dialogue = {}Dialogue(\n".format(
-            self.protocol_specification_in_camel_case
-        )
-        self._change_indent(1)
-        cls_str += (
-            self.indent
-            + "dialogue_label=dialogue_label, agent_address=self.agent_address, role=role\n"
-        )
+        cls_str += self.indent + "dialogue_class=dialogue_class,\n"
+        cls_str += self.indent + "role_from_first_message=role_from_first_message,\n"
         self._change_indent(-1)
         cls_str += self.indent + ")\n"
-        cls_str += self.indent + "return dialogue\n"
         self._change_indent(-2)
         cls_str += self.indent + "\n"
 
@@ -1487,7 +1447,6 @@ class ProtocolGenerator:
                     self.protocol_specification.name, performative, content_name
                 )
                 self._change_indent(1)
-                # no_indents += 1
             decoding_str += self._decoding_message_content_from_protobuf_to_python(
                 performative, content_name, sub_type
             )
@@ -1862,7 +1821,6 @@ class ProtocolGenerator:
                 self._change_indent(-1)
                 proto_buff_schema_str += self.indent + "}\n\n"
         proto_buff_schema_str += "\n"
-        # self._change_indent(-1)
 
         # meta-data
         proto_buff_schema_str += self.indent + "// Standard {}Message fields\n".format(
@@ -1900,6 +1858,9 @@ class ProtocolGenerator:
         protocol_yaml_str = "name: {}\n".format(self.protocol_specification.name)
         protocol_yaml_str += "author: {}\n".format(self.protocol_specification.author)
         protocol_yaml_str += "version: {}\n".format(self.protocol_specification.version)
+        protocol_yaml_str += "type: {}\n".format(
+            self.protocol_specification.component_type
+        )
         protocol_yaml_str += "description: {}\n".format(
             self.protocol_specification.description
         )
