@@ -285,10 +285,7 @@ def is_installed(programme: str) -> bool:
     :return: True if installed, False otherwise
     """
     res = shutil.which(programme)
-    if res is None:
-        return False
-    else:
-        return True
+    return res is not None
 
 
 def check_prerequisites() -> None:
@@ -364,7 +361,6 @@ def try_run_protoc(path_to_generated_protocol_package, name) -> None:
 
     :return: A completed process object.
     """
-    # command: "protoc -I={} --python_out={} {}/{}.proto"
     subprocess.run(  # nosec
         [
             "protoc",
