@@ -26,6 +26,7 @@ import yaml
 from aea.cli.utils.config import handle_dotted_path
 from aea.configurations.base import PublicId
 from aea.connections.stub.connection import write_envelope
+from aea.exceptions import enforce
 from aea.mail.base import Envelope
 
 
@@ -54,13 +55,13 @@ def read_envelope_from_file(file_path: str):
     with open(Path(file_path), "rb+") as f:
         lines.extend(f.readlines())
 
-    assert len(lines) == 2, "Did not find two lines."
+    enforce(len(lines) == 2, "Did not find two lines.")
     line = lines[0] + lines[1]
     to_b, sender_b, protocol_id_b, message, end = line.strip().split(b",", maxsplit=4)
     to = to_b.decode("utf-8")
     sender = sender_b.decode("utf-8")
     protocol_id = PublicId.from_str(protocol_id_b.decode("utf-8"))
-    assert end in [b"", b"\n"]
+    enforce(end in [b"", b"\n"], "Envelope improperly formatted.")
 
     return Envelope(to=to, sender=sender, protocol_id=protocol_id, message=message,)
 
