@@ -19,22 +19,23 @@
 """Extension to the Local Node."""
 
 import asyncio
-import copy
 import logging
 from asyncio import AbstractEventLoop, Queue
 from collections import defaultdict
 from threading import Thread
 from typing import Dict, List, Optional, Tuple, cast
 
+from aea.common import Address
 from aea.configurations.base import ProtocolId, PublicId
 from aea.connections.base import Connection, ConnectionStates
 from aea.helpers.search.models import Description
-from aea.mail.base import AEAConnectionError, Address, Envelope
+from aea.mail.base import Envelope, Message
 from aea.protocols.default.message import DefaultMessage
+from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 
+from packages.fetchai.protocols.oef_search.dialogues import OefSearchDialogue
 from packages.fetchai.protocols.oef_search.dialogues import (
-    OefSearchDialogue,
-    OefSearchDialogues,
+    OefSearchDialogues as BaseOefSearchDialogues,
 )
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 
@@ -45,7 +46,37 @@ MESSAGE_ID = 1
 RESPONSE_TARGET = MESSAGE_ID
 RESPONSE_MESSAGE_ID = MESSAGE_ID + 1
 STUB_DIALOGUE_ID = 0
-PUBLIC_ID = PublicId.from_str("fetchai/local:0.6.0")
+PUBLIC_ID = PublicId.from_str("fetchai/local:0.8.0")
+
+
+class OefSearchDialogues(BaseOefSearchDialogues):
+    """The dialogues class keeps track of all dialogues."""
+
+    def __init__(self, **kwargs) -> None:
+        """
+        Initialize dialogues.
+
+        :return: None
+        """
+
+        def role_from_first_message(  # pylint: disable=unused-argument
+            message: Message, receiver_address: Address
+        ) -> BaseDialogue.Role:
+            """Infer the role of the agent from an incoming/outgoing first message
+
+            :param message: an incoming/outgoing first message
+            :param receiver_address: the address of the receiving agent
+            :return: The role of the agent
+            """
+            # The local connection maintains the dialogue on behalf of the node
+            return OefSearchDialogue.Role.OEF_NODE
+
+        BaseOefSearchDialogues.__init__(
+            self,
+            self_address=str(OEFLocalConnection.connection_id),
+            role_from_first_message=role_from_first_message,
+            **kwargs,
+        )
 
 
 class LocalNode:
@@ -105,14 +136,13 @@ class LocalNode:
         if address in self._out_queues.keys():
             return None
 
-        assert self._in_queue is not None
+        if self._in_queue is None:  # pragma: nocover
+            raise ValueError("In queue not set.")
         q = self._in_queue  # type: asyncio.Queue
         self._out_queues[address] = writer
 
         self.address = address
-        self._dialogues = OefSearchDialogues(
-            agent_address=str(OEFLocalConnection.connection_id)
-        )
+        self._dialogues = OefSearchDialogues()
         return q
 
     def start(self):
@@ -150,7 +180,7 @@ class LocalNode:
         :param envelope: the envelope
         :return: None
         """
-        if envelope.protocol_id == ProtocolId.from_str("fetchai/oef_search:0.4.0"):
+        if envelope.protocol_id == ProtocolId.from_str("fetchai/oef_search:0.6.0"):
             await self._handle_oef_message(envelope)
         else:
             await self._handle_agent_message(envelope)
@@ -161,9 +191,8 @@ class LocalNode:
         :param envelope: the envelope
         :return: None
         """
-        assert isinstance(
-            envelope.message, OefSearchMessage
-        ), "Message not of type OefSearchMessage"
+        if not isinstance(envelope.message, OefSearchMessage):  # pragma: nocover
+            raise ValueError("Message not of type OefSearchMessage.")
         oef_message, dialogue = self._get_message_and_dialogue(envelope)
 
         if dialogue is None:
@@ -203,7 +232,7 @@ class LocalNode:
                 message_id=MESSAGE_ID,
                 error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
                 error_msg="Destination not available",
-                error_data={},  # TODO: reference incoming message.
+                error_data={},
             )
             error_envelope = Envelope(
                 to=envelope.sender,
@@ -213,8 +242,7 @@ class LocalNode:
             )
             await self._send(error_envelope)
             return
-        else:
-            await self._send(envelope)
+        await self._send(envelope)
 
     async def _register_service(
         self, address: Address, service_description: Description
@@ -243,17 +271,13 @@ class LocalNode:
         address = oef_search_msg.sender
         async with self._lock:
             if address not in self.services:
-                msg = OefSearchMessage(
+                msg = dialogue.reply(
                     performative=OefSearchMessage.Performative.OEF_ERROR,
-                    target=oef_search_msg.message_id,
-                    message_id=oef_search_msg.message_id + 1,
+                    target_message=oef_search_msg,
                     oef_error_operation=OefSearchMessage.OefErrorOperation.UNREGISTER_SERVICE,
-                    dialogue_reference=dialogue.dialogue_label.dialogue_reference,
                 )
-                msg.counterparty = oef_search_msg.sender
-                assert dialogue.update(msg)
                 envelope = Envelope(
-                    to=msg.counterparty,
+                    to=msg.to,
                     sender=msg.sender,
                     protocol_id=msg.protocol_id,
                     message=msg,
@@ -288,21 +312,14 @@ class LocalNode:
                         if description.data_model == query.model:
                             result.append(agent_address)
 
-            msg = OefSearchMessage(
+            msg = dialogue.reply(
                 performative=OefSearchMessage.Performative.SEARCH_RESULT,
-                target=oef_search_msg.message_id,
-                dialogue_reference=dialogue.dialogue_label.dialogue_reference,
-                message_id=oef_search_msg.message_id + 1,
+                target_message=oef_search_msg,
                 agents=tuple(sorted(set(result))),
             )
-            msg.counterparty = oef_search_msg.sender
-            assert dialogue.update(msg)
 
             envelope = Envelope(
-                to=msg.counterparty,
-                sender=msg.sender,
-                protocol_id=msg.protocol_id,
-                message=msg,
+                to=msg.to, sender=msg.sender, protocol_id=msg.protocol_id, message=msg,
             )
             await self._send(envelope)
 
@@ -314,17 +331,11 @@ class LocalNode:
 
         :param envelope: incoming envelope
 
-        :return: Tuple[MEssage, Optional[Dialogue]]
+        :return: Tuple[Message, Optional[Dialogue]]
         """
-        assert self._dialogues is not None, "Call connect before!"
-        message_orig = cast(OefSearchMessage, envelope.message)
-        message = copy.copy(
-            message_orig
-        )  # TODO: fix; need to copy atm to avoid overwriting "is_incoming"
-        message.is_incoming = True  # TODO: fix; should be done by framework
-        message.counterparty = (
-            message_orig.sender
-        )  # TODO: fix; should be done by framework
+        if self._dialogues is None:  # pragma: nocover
+            raise ValueError("Call connect before!")
+        message = cast(OefSearchMessage, envelope.message)
         dialogue = cast(OefSearchDialogue, self._dialogues.update(message))
         return message, dialogue
 
@@ -372,21 +383,25 @@ class OEFLocalConnection(Connection):
 
     async def connect(self) -> None:
         """Connect to the local OEF Node."""
-        assert self._local_node is not None, "No local node set!"
-        if self.is_connected:
-            return  # pragma: nocover
-        self._state.set(ConnectionStates.connecting)
-        self._reader = Queue()
-        self._writer = await self._local_node.connect(self.address, self._reader)
-        self._state.set(ConnectionStates.connected)
+        if self._local_node is None:  # pragma: nocover
+            raise ValueError("No local node set!")
+
+        if self.is_connected:  # pragma: nocover
+            return
+
+        with self._connect_context():
+            self._reader = Queue()
+            self._writer = await self._local_node.connect(self.address, self._reader)
 
     async def disconnect(self) -> None:
         """Disconnect from the local OEF Node."""
-        assert self._local_node is not None, "No local node set!"
+        if self._local_node is None:
+            raise ValueError("No local node set!")  # pragma: nocover
         if self.is_disconnected:
             return  # pragma: nocover
         self._state.set(ConnectionStates.disconnecting)
-        assert self._reader is not None
+        if self._reader is None:
+            raise ValueError("No reader set!")  # pragma: nocover
         await self._local_node.disconnect(self.address)
         await self._reader.put(None)
         self._reader, self._writer = None, None
@@ -394,10 +409,7 @@ class OEFLocalConnection(Connection):
 
     async def send(self, envelope: Envelope):
         """Send a message."""
-        if not self.is_connected:
-            raise AEAConnectionError(
-                "Connection not established yet. Please use 'connect()'."
-            )
+        self._ensure_connected()
         self._writer._loop.call_soon_threadsafe(self._writer.put_nowait, envelope)  # type: ignore  # pylint: disable=protected-access
 
     async def receive(self, *args, **kwargs) -> Optional["Envelope"]:
@@ -406,14 +418,12 @@ class OEFLocalConnection(Connection):
 
         :return: the envelope received, or None.
         """
-        if not self.is_connected:
-            raise AEAConnectionError(
-                "Connection not established yet. Please use 'connect()'."
-            )
+        self._ensure_connected()
         try:
-            assert self._reader is not None
+            if self._reader is None:
+                raise ValueError("No reader set!")  # pragma: nocover
             envelope = await self._reader.get()
-            if envelope is None:
+            if envelope is None:  # pragma: no cover
                 self.logger.debug("Receiving task terminated.")
                 return None
             self.logger.debug("Received envelope {}".format(envelope))
