@@ -59,7 +59,7 @@ RESPONSE_MESSAGE_ID = MESSAGE_ID + 1
 STUB_MESSAGE_ID = 0
 STUB_DIALOGUE_ID = 0
 DEFAULT_OEF = "oef"
-PUBLIC_ID = PublicId.from_str("fetchai/oef:0.8.0")
+PUBLIC_ID = PublicId.from_str("fetchai/oef:0.9.0")
 
 
 class OefSearchDialogue(BaseOefSearchDialogue):
@@ -411,7 +411,7 @@ class OEFChannel(OEFAgent):
                 )
                 raise ValueError("Cannot send message.")
 
-        if envelope.protocol_id == PublicId.from_str("fetchai/oef_search:0.5.0"):
+        if envelope.protocol_id == PublicId.from_str("fetchai/oef_search:0.6.0"):
             self.send_oef_message(envelope)
         else:
             self.send_default_message(envelope)
@@ -621,7 +621,7 @@ class OEFConnection(Connection):
         """
         try:
             envelope = await self.channel.get()
-            if envelope is None:
+            if envelope is None:  # pragma: no cover
                 self.logger.debug("Received None.")
                 return None
             self.logger.debug("Received envelope: {}".format(envelope))
