@@ -20,10 +20,10 @@
 """This module contains fipa's message definition."""
 
 import logging
-from enum import Enum
 from typing import Dict, Set, Tuple, cast
 
 from aea.configurations.base import ProtocolId
+from aea.exceptions import AEAEnforceError, enforce
 from aea.protocols.base import Message
 
 from packages.fetchai.protocols.fipa.custom_types import (
@@ -39,13 +39,13 @@ DEFAULT_BODY_SIZE = 4
 class FipaMessage(Message):
     """A protocol for FIPA ACL."""
 
-    protocol_id = ProtocolId("fetchai", "fipa", "0.3.0")
+    protocol_id = ProtocolId.from_str("fetchai/fipa:0.6.0")
 
     Description = CustomDescription
 
     Query = CustomQuery
 
-    class Performative(Enum):
+    class Performative(Message.Performative):
         """Performatives for the fipa protocol."""
 
         ACCEPT = "accept"
@@ -77,13 +77,6 @@ class FipaMessage(Message):
         :param target: the message target.
         :param performative: the message performative.
         """
-        super().__init__(
-            dialogue_reference=dialogue_reference,
-            message_id=message_id,
-            target=target,
-            performative=FipaMessage.Performative(performative),
-            **kwargs,
-        )
         self._performatives = {
             "accept",
             "accept_w_inform",
@@ -94,6 +87,13 @@ class FipaMessage(Message):
             "match_accept_w_inform",
             "propose",
         }
+        super().__init__(
+            dialogue_reference=dialogue_reference,
+            message_id=message_id,
+            target=target,
+            performative=FipaMessage.Performative(performative),
+            **kwargs,
+        )
 
     @property
     def valid_performatives(self) -> Set[str]:
@@ -103,80 +103,86 @@ class FipaMessage(Message):
     @property
     def dialogue_reference(self) -> Tuple[str, str]:
         """Get the dialogue_reference of the message."""
-        assert self.is_set("dialogue_reference"), "dialogue_reference is not set."
+        enforce(self.is_set("dialogue_reference"), "dialogue_reference is not set.")
         return cast(Tuple[str, str], self.get("dialogue_reference"))
 
     @property
     def message_id(self) -> int:
         """Get the message_id of the message."""
-        assert self.is_set("message_id"), "message_id is not set."
+        enforce(self.is_set("message_id"), "message_id is not set.")
         return cast(int, self.get("message_id"))
 
     @property
-    def performative(self) -> Performative:  # noqa: F821
+    def performative(self) -> Performative:  # type: ignore # noqa: F821
         """Get the performative of the message."""
-        assert self.is_set("performative"), "performative is not set."
+        enforce(self.is_set("performative"), "performative is not set.")
         return cast(FipaMessage.Performative, self.get("performative"))
 
     @property
     def target(self) -> int:
         """Get the target of the message."""
-        assert self.is_set("target"), "target is not set."
+        enforce(self.is_set("target"), "target is not set.")
         return cast(int, self.get("target"))
 
     @property
     def info(self) -> Dict[str, str]:
         """Get the 'info' content from the message."""
-        assert self.is_set("info"), "'info' content is not set."
+        enforce(self.is_set("info"), "'info' content is not set.")
         return cast(Dict[str, str], self.get("info"))
 
     @property
     def proposal(self) -> CustomDescription:
         """Get the 'proposal' content from the message."""
-        assert self.is_set("proposal"), "'proposal' content is not set."
+        enforce(self.is_set("proposal"), "'proposal' content is not set.")
         return cast(CustomDescription, self.get("proposal"))
 
     @property
     def query(self) -> CustomQuery:
         """Get the 'query' content from the message."""
-        assert self.is_set("query"), "'query' content is not set."
+        enforce(self.is_set("query"), "'query' content is not set.")
         return cast(CustomQuery, self.get("query"))
 
     def _is_consistent(self) -> bool:
         """Check that the message follows the fipa protocol."""
         try:
-            assert (
-                type(self.dialogue_reference) == tuple
-            ), "Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.".format(
-                type(self.dialogue_reference)
+            enforce(
+                type(self.dialogue_reference) == tuple,
+                "Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.".format(
+                    type(self.dialogue_reference)
+                ),
             )
-            assert (
-                type(self.dialogue_reference[0]) == str
-            ), "Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.".format(
-                type(self.dialogue_reference[0])
+            enforce(
+                type(self.dialogue_reference[0]) == str,
+                "Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.".format(
+                    type(self.dialogue_reference[0])
+                ),
             )
-            assert (
-                type(self.dialogue_reference[1]) == str
-            ), "Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.".format(
-                type(self.dialogue_reference[1])
+            enforce(
+                type(self.dialogue_reference[1]) == str,
+                "Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.".format(
+                    type(self.dialogue_reference[1])
+                ),
             )
-            assert (
-                type(self.message_id) == int
-            ), "Invalid type for 'message_id'. Expected 'int'. Found '{}'.".format(
-                type(self.message_id)
+            enforce(
+                type(self.message_id) == int,
+                "Invalid type for 'message_id'. Expected 'int'. Found '{}'.".format(
+                    type(self.message_id)
+                ),
             )
-            assert (
-                type(self.target) == int
-            ), "Invalid type for 'target'. Expected 'int'. Found '{}'.".format(
-                type(self.target)
+            enforce(
+                type(self.target) == int,
+                "Invalid type for 'target'. Expected 'int'. Found '{}'.".format(
+                    type(self.target)
+                ),
             )
 
             # Light Protocol Rule 2
             # Check correct performative
-            assert (
-                type(self.performative) == FipaMessage.Performative
-            ), "Invalid 'performative'. Expected either of '{}'. Found '{}'.".format(
-                self.valid_performatives, self.performative
+            enforce(
+                type(self.performative) == FipaMessage.Performative,
+                "Invalid 'performative'. Expected either of '{}'. Found '{}'.".format(
+                    self.valid_performatives, self.performative
+                ),
             )
 
             # Check correct contents
@@ -184,71 +190,82 @@ class FipaMessage(Message):
             expected_nb_of_contents = 0
             if self.performative == FipaMessage.Performative.CFP:
                 expected_nb_of_contents = 1
-                assert (
-                    type(self.query) == CustomQuery
-                ), "Invalid type for content 'query'. Expected 'Query'. Found '{}'.".format(
-                    type(self.query)
+                enforce(
+                    type(self.query) == CustomQuery,
+                    "Invalid type for content 'query'. Expected 'Query'. Found '{}'.".format(
+                        type(self.query)
+                    ),
                 )
             elif self.performative == FipaMessage.Performative.PROPOSE:
                 expected_nb_of_contents = 1
-                assert (
-                    type(self.proposal) == CustomDescription
-                ), "Invalid type for content 'proposal'. Expected 'Description'. Found '{}'.".format(
-                    type(self.proposal)
+                enforce(
+                    type(self.proposal) == CustomDescription,
+                    "Invalid type for content 'proposal'. Expected 'Description'. Found '{}'.".format(
+                        type(self.proposal)
+                    ),
                 )
             elif self.performative == FipaMessage.Performative.ACCEPT_W_INFORM:
                 expected_nb_of_contents = 1
-                assert (
-                    type(self.info) == dict
-                ), "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
-                    type(self.info)
+                enforce(
+                    type(self.info) == dict,
+                    "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
+                        type(self.info)
+                    ),
                 )
                 for key_of_info, value_of_info in self.info.items():
-                    assert (
-                        type(key_of_info) == str
-                    ), "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(key_of_info)
+                    enforce(
+                        type(key_of_info) == str,
+                        "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(key_of_info)
+                        ),
                     )
-                    assert (
-                        type(value_of_info) == str
-                    ), "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(value_of_info)
+                    enforce(
+                        type(value_of_info) == str,
+                        "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(value_of_info)
+                        ),
                     )
             elif self.performative == FipaMessage.Performative.MATCH_ACCEPT_W_INFORM:
                 expected_nb_of_contents = 1
-                assert (
-                    type(self.info) == dict
-                ), "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
-                    type(self.info)
+                enforce(
+                    type(self.info) == dict,
+                    "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
+                        type(self.info)
+                    ),
                 )
                 for key_of_info, value_of_info in self.info.items():
-                    assert (
-                        type(key_of_info) == str
-                    ), "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(key_of_info)
+                    enforce(
+                        type(key_of_info) == str,
+                        "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(key_of_info)
+                        ),
                     )
-                    assert (
-                        type(value_of_info) == str
-                    ), "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(value_of_info)
+                    enforce(
+                        type(value_of_info) == str,
+                        "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(value_of_info)
+                        ),
                     )
             elif self.performative == FipaMessage.Performative.INFORM:
                 expected_nb_of_contents = 1
-                assert (
-                    type(self.info) == dict
-                ), "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
-                    type(self.info)
+                enforce(
+                    type(self.info) == dict,
+                    "Invalid type for content 'info'. Expected 'dict'. Found '{}'.".format(
+                        type(self.info)
+                    ),
                 )
                 for key_of_info, value_of_info in self.info.items():
-                    assert (
-                        type(key_of_info) == str
-                    ), "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(key_of_info)
+                    enforce(
+                        type(key_of_info) == str,
+                        "Invalid type for dictionary keys in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(key_of_info)
+                        ),
                     )
-                    assert (
-                        type(value_of_info) == str
-                    ), "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
-                        type(value_of_info)
+                    enforce(
+                        type(value_of_info) == str,
+                        "Invalid type for dictionary values in content 'info'. Expected 'str'. Found '{}'.".format(
+                            type(value_of_info)
+                        ),
                     )
             elif self.performative == FipaMessage.Performative.ACCEPT:
                 expected_nb_of_contents = 0
@@ -258,26 +275,29 @@ class FipaMessage(Message):
                 expected_nb_of_contents = 0
 
             # Check correct content count
-            assert (
-                expected_nb_of_contents == actual_nb_of_contents
-            ), "Incorrect number of contents. Expected {}. Found {}".format(
-                expected_nb_of_contents, actual_nb_of_contents
+            enforce(
+                expected_nb_of_contents == actual_nb_of_contents,
+                "Incorrect number of contents. Expected {}. Found {}".format(
+                    expected_nb_of_contents, actual_nb_of_contents
+                ),
             )
 
             # Light Protocol Rule 3
             if self.message_id == 1:
-                assert (
-                    self.target == 0
-                ), "Invalid 'target'. Expected 0 (because 'message_id' is 1). Found {}.".format(
-                    self.target
+                enforce(
+                    self.target == 0,
+                    "Invalid 'target'. Expected 0 (because 'message_id' is 1). Found {}.".format(
+                        self.target
+                    ),
                 )
             else:
-                assert (
-                    0 < self.target < self.message_id
-                ), "Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.".format(
-                    self.message_id - 1, self.target,
+                enforce(
+                    0 < self.target < self.message_id,
+                    "Invalid 'target'. Expected an integer between 1 and {} inclusive. Found {}.".format(
+                        self.message_id - 1, self.target,
+                    ),
                 )
-        except (AssertionError, ValueError, KeyError) as e:
+        except (AEAEnforceError, ValueError, KeyError) as e:
             logger.error(str(e))
             return False
 
