@@ -47,7 +47,7 @@ from packages.fetchai.skills.erc1155_client.dialogues import (
 )
 from packages.fetchai.skills.erc1155_client.strategy import Strategy
 
-LEDGER_API_ADDRESS = "fetchai/ledger:0.4.0"
+LEDGER_API_ADDRESS = "fetchai/ledger:0.5.0"
 
 
 class FipaHandler(Handler):
@@ -414,7 +414,7 @@ class ContractApiHandler(Handler):
         self.context.logger.info("received raw message={}".format(contract_api_msg))
         signing_dialogues = cast(SigningDialogues, self.context.signing_dialogues)
         signing_msg, signing_dialogue = signing_dialogues.create(
-            counterparty="decision_maker",
+            counterparty=self.context.decision_maker_address,
             performative=SigningMessage.Performative.SIGN_MESSAGE,
             raw_message=RawMessage(
                 contract_api_msg.raw_message.ledger_id,
