@@ -44,7 +44,7 @@ from packages.fetchai.skills.generic_buyer.dialogues import (
 )
 from packages.fetchai.skills.generic_buyer.strategy import GenericStrategy
 
-LEDGER_API_ADDRESS = "fetchai/ledger:0.4.0"
+LEDGER_API_ADDRESS = "fetchai/ledger:0.5.0"
 
 
 class GenericFipaHandler(Handler):
@@ -609,7 +609,7 @@ class GenericLedgerApiHandler(Handler):
         self.context.logger.info("received raw transaction={}".format(ledger_api_msg))
         signing_dialogues = cast(SigningDialogues, self.context.signing_dialogues)
         signing_msg, signing_dialogue = signing_dialogues.create(
-            counterparty="decision_maker",
+            counterparty=self.context.decision_maker_address,
             performative=SigningMessage.Performative.SIGN_TRANSACTION,
             raw_transaction=ledger_api_msg.raw_transaction,
             terms=ledger_api_dialogue.associated_fipa_dialogue.terms,
