@@ -19,7 +19,9 @@
 
 """This module contains the strategy class."""
 
+from aea.common import Address
 from aea.configurations.constants import DEFAULT_LEDGER
+from aea.exceptions import enforce
 from aea.helpers.search.generic import SIMPLE_SERVICE_MODEL
 from aea.helpers.search.models import (
     Constraint,
@@ -29,7 +31,6 @@ from aea.helpers.search.models import (
     Query,
 )
 from aea.helpers.transaction.base import Terms
-from aea.mail.base import Address
 from aea.skills.base import Model
 
 DEFAULT_LEDGER_ID = DEFAULT_LEDGER
@@ -101,7 +102,7 @@ class GenericStrategy(Model):
     @is_searching.setter
     def is_searching(self, is_searching: bool) -> None:
         """Check if the agent is searching."""
-        assert isinstance(is_searching, bool), "Can only set bool on is_searching!"
+        enforce(isinstance(is_searching, bool), "Can only set bool on is_searching!")
         self._is_searching = is_searching
 
     @property
