@@ -24,7 +24,6 @@ import time
 from typing import Optional, Tuple, cast
 
 from aea.configurations.base import ProtocolId
-from aea.helpers.dialogue.base import DialogueLabel
 from aea.helpers.search.models import Query
 from aea.protocols.base import Message
 from aea.protocols.default.message import DefaultMessage
@@ -111,17 +110,13 @@ class FipaNegotiationHandler(Handler):
             "received invalid fipa message={}, unidentified dialogue.".format(fipa_msg)
         )
         default_dialogues = cast(DefaultDialogues, self.context.default_dialogues)
-        default_msg = DefaultMessage(
+        default_msg, _ = default_dialogues.create(
+            counterparty=fipa_msg.sender,
             performative=DefaultMessage.Performative.ERROR,
-            dialogue_reference=default_dialogues.new_self_initiated_dialogue_reference(),
             error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
             error_msg="Invalid dialogue.",
             error_data={"fipa_message": fipa_msg.encode()},
         )
-        default_msg.counterparty = fipa_msg.counterparty
-        assert (
-            default_dialogues.update(default_msg) is not None
-        ), "DefaultDialogue not constructed."
         self.context.outbox.put_message(message=default_msg)
 
     def _on_cfp(self, cfp: FipaMessage, fipa_dialogue: FipaDialogue) -> None:
@@ -156,11 +151,8 @@ class FipaNegotiationHandler(Handler):
                     ),
                 )
             )
-            fipa_msg = FipaMessage(
-                performative=FipaMessage.Performative.DECLINE,
-                message_id=new_msg_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=cfp.message_id,
+            fipa_msg = fipa_dialogue.reply(
+                performative=FipaMessage.Performative.DECLINE, target_message=cfp,
             )
             fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
             fipa_dialogues.dialogue_stats.add_dialogue_endstate(
@@ -171,7 +163,7 @@ class FipaNegotiationHandler(Handler):
             signing_msg = transactions.generate_signing_message(
                 SigningMessage.Performative.SIGN_MESSAGE,
                 proposal_description,
-                fipa_dialogue.dialogue_label,
+                fipa_dialogue,
                 cast(FipaDialogue.Role, fipa_dialogue.role),
                 self.context.agent_address,
             )
@@ -194,15 +186,11 @@ class FipaNegotiationHandler(Handler):
                     ),
                 )
             )
-            fipa_msg = FipaMessage(
+            fipa_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.PROPOSE,
-                message_id=new_msg_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=cfp.message_id,
+                target_message=cfp,
                 proposal=proposal_description,
             )
-        fipa_msg.counterparty = cfp.counterparty
-        fipa_dialogue.update(fipa_msg)
         self.context.outbox.put_message(message=fipa_msg)
 
     def _on_propose(self, propose: FipaMessage, fipa_dialogue: FipaDialogue) -> None:
@@ -221,7 +209,7 @@ class FipaNegotiationHandler(Handler):
         signing_msg = transactions.generate_signing_message(
             SigningMessage.Performative.SIGN_MESSAGE,
             proposal_description,
-            fipa_dialogue.dialogue_label,
+            fipa_dialogue,
             cast(FipaDialogue.Role, fipa_dialogue.role),
             self.context.agent_address,
         )
@@ -238,28 +226,20 @@ class FipaNegotiationHandler(Handler):
             transactions.add_pending_initial_acceptance(
                 fipa_dialogue.dialogue_label, new_msg_id, signing_msg
             )
-            fipa_msg = FipaMessage(
-                performative=FipaMessage.Performative.ACCEPT,
-                message_id=new_msg_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=propose.message_id,
+            fipa_msg = fipa_dialogue.reply(
+                performative=FipaMessage.Performative.ACCEPT, target_message=propose,
             )
         else:
             self.context.logger.info(
                 "declining propose (as {})".format(fipa_dialogue.role)
             )
-            fipa_msg = FipaMessage(
-                performative=FipaMessage.Performative.DECLINE,
-                message_id=new_msg_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=propose.message_id,
+            fipa_msg = fipa_dialogue.reply(
+                performative=FipaMessage.Performative.DECLINE, target_message=propose,
             )
             fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
             fipa_dialogues.dialogue_stats.add_dialogue_endstate(
                 FipaDialogue.EndState.DECLINED_PROPOSE, fipa_dialogue.is_self_initiated
             )
-        fipa_msg.counterparty = propose.counterparty
-        fipa_dialogue.update(fipa_msg)
         self.context.outbox.put_message(message=fipa_msg)
 
     def _on_decline(self, decline: FipaMessage, fipa_dialogue: FipaDialogue) -> None:
@@ -319,7 +299,6 @@ class FipaNegotiationHandler(Handler):
                 accept.target,
             )
         )
-        new_msg_id = accept.message_id + 1
         transactions = cast(Transactions, self.context.transactions)
         signing_msg = transactions.pop_pending_proposal(
             fipa_dialogue.dialogue_label, accept.target
@@ -337,62 +316,54 @@ class FipaNegotiationHandler(Handler):
             )
             if strategy.is_contract_tx:
                 pass
-                # contract = cast(ERC1155Contract, self.context.contracts.erc1155)
-                # if not contract.is_deployed:
-                #     ledger_api = self.context.ledger_apis.get_api(strategy.ledger_id)
-                #     contract_address = self.context.shared_state.get(
-                #         "erc1155_contract_address", None
-                #     )
-                #     assert (
-                #         contract_address is not None
-                #     ), "ERC1155Contract address not set!"
-                # tx_nonce = transaction_msg.skill_callback_info.get("tx_nonce", None)
-                # assert tx_nonce is not None, "tx_nonce must be provided"
-                # transaction_msg = contract.get_hash_batch_transaction_msg(
-                #     from_address=accept.counterparty,
-                #     to_address=self.context.agent_address,  # must match self
-                #     token_ids=[
-                #         int(key)
-                #         for key in transaction_msg.terms.quantities_by_good_id.keys()
-                #     ]
-                #     + [
-                #         int(key)
-                #         for key in transaction_msg.terms.amount_by_currency_id.keys()
-                #     ],
-                #     from_supplies=[
-                #         quantity if quantity > 0 else 0
-                #         for quantity in transaction_msg.terms.quantities_by_good_id.values()
-                #     ]
-                #     + [
-                #         value if value > 0 else 0
-                #         for value in transaction_msg.terms.amount_by_currency_id.values()
-                #     ],
-                #     to_supplies=[
-                #         -quantity if quantity < 0 else 0
-                #         for quantity in transaction_msg.terms.quantities_by_good_id.values()
-                #     ]
-                #     + [
-                #         -value if value < 0 else 0
-                #         for value in transaction_msg.terms.amount_by_currency_id.values()
-                #     ],
-                #     value=0,
-                #     trade_nonce=int(tx_nonce),
-                #     ledger_api=self.context.ledger_apis.get_api(strategy.ledger_id),
-                #     skill_callback_id=self.context.skill_id,
-                #     skill_callback_info={
-                #         "dialogue_label": fipa_dialogue.dialogue_label.json
-                #     },
-                # )
+                # contract = cast(ERC1155Contract, self.context.contracts.erc1155) # noqa: E800
+                # if not contract.is_deployed: # noqa: E800
+                #     ledger_api = self.context.ledger_apis.get_api(strategy.ledger_id) # noqa: E800
+                #     contract_address = self.context.shared_state.get( # noqa: E800
+                #         "erc1155_contract_address", None # noqa: E800
+                #     ) # noqa: E800
+                #     enforce( # noqa: E800
+                #         contract_address is not None, # noqa: E800
+                #         "ERC1155Contract address not set!" # noqa: E800
+                #     ) # noqa: E800
+                # tx_nonce = transaction_msg.skill_callback_info.get("tx_nonce", None) # noqa: E800
+                # enforce(tx_nonce is not None, "tx_nonce must be provided") # noqa: E800
+                # transaction_msg = contract.get_hash_batch_transaction_msg( # noqa: E800
+                #     from_address=accept.counterparty, # noqa: E800
+                #     to_address=self.context.agent_address,  # must match self # noqa: E800
+                #     token_ids=[ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in transaction_msg.terms.quantities_by_good_id.keys() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in transaction_msg.terms.amount_by_currency_id.keys() # noqa: E800
+                #     ], # noqa: E800
+                #     from_supplies=[ # noqa: E800
+                #         quantity if quantity > 0 else 0 # noqa: E800
+                #         for quantity in transaction_msg.terms.quantities_by_good_id.values() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         value if value > 0 else 0 # noqa: E800
+                #         for value in transaction_msg.terms.amount_by_currency_id.values() # noqa: E800
+                #     ], # noqa: E800
+                #     to_supplies=[ # noqa: E800
+                #         -quantity if quantity < 0 else 0 # noqa: E800
+                #         for quantity in transaction_msg.terms.quantities_by_good_id.values() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         -value if value < 0 else 0 # noqa: E800
+                #         for value in transaction_msg.terms.amount_by_currency_id.values() # noqa: E800
+                #     ], # noqa: E800
+                #     value=0, # noqa: E800
+                #     trade_nonce=int(tx_nonce), # noqa: E800
+                #     ledger_api=self.context.ledger_apis.get_api(strategy.ledger_id), # noqa: E800
+                #     skill_callback_id=self.context.skill_id, # noqa: E800
+                #     skill_callback_info={ # noqa: E800
+                #         "dialogue_label": fipa_dialogue.dialogue_label.json # noqa: E800
+                #     }, # noqa: E800
+                # ) # noqa: E800
             else:
-                signing_dialogues = cast(
-                    SigningDialogues, self.context.signing_dialogues
-                )
-                signing_dialogue = cast(
-                    Optional[SigningDialogue], signing_dialogues.update(signing_msg)
-                )
-                assert (
-                    signing_dialogue is not None
-                ), "Could not construct sigining dialogue."
                 self.context.logger.info(
                     "sending signing_msg={} to decison maker following ACCEPT.".format(
                         signing_msg
@@ -403,14 +374,9 @@ class FipaNegotiationHandler(Handler):
             self.context.logger.debug(
                 "decline the Accept (as {}).".format(fipa_dialogue.role)
             )
-            fipa_msg = FipaMessage(
-                performative=FipaMessage.Performative.DECLINE,
-                message_id=new_msg_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=accept.message_id,
+            fipa_msg = fipa_dialogue.reply(
+                performative=FipaMessage.Performative.DECLINE, target_message=accept,
             )
-            fipa_msg.counterparty = accept.counterparty
-            fipa_dialogue.update(fipa_msg)
             dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
             dialogues.dialogue_stats.add_dialogue_endstate(
                 FipaDialogue.EndState.DECLINED_ACCEPT, fipa_dialogue.is_self_initiated
@@ -440,81 +406,77 @@ class FipaNegotiationHandler(Handler):
             signing_msg = transactions.pop_pending_initial_acceptance(
                 fipa_dialogue.dialogue_label, match_accept.target
             )
+            signing_dialogues = cast(SigningDialogues, self.context.signing_dialogues)
+            signing_dialogue = cast(
+                Optional[SigningDialogue], signing_dialogues.get_dialogue(signing_msg)
+            )
+            if signing_dialogue is None:
+                raise ValueError("Could not recover dialogue.")
             strategy = cast(Strategy, self.context.strategy)
             counterparty_signature = match_accept.info.get("signature")
+            if counterparty_signature is None:
+                self.context.logger.warning("No signature from counterparty.")
+                return
+            signing_dialogue.counterparty_signature = counterparty_signature
             if strategy.is_contract_tx:
                 pass
-                # contract = cast(ERC1155Contract, self.context.contracts.erc1155)
-                # if not contract.is_deployed:
-                #     ledger_api = self.context.ledger_apis.get_api(strategy.ledger_id)
-                #     contract_address = self.context.shared_state.get(
-                #         "erc1155_contract_address", None
-                #     )
-                #     assert (
-                #         contract_address is not None
-                #     ), "ERC1155Contract address not set!"
-                #     contract.set_deployed_instance(
-                #         ledger_api, cast(str, contract_address),
-                #     )
-                # strategy = cast(Strategy, self.context.strategy)
-                # tx_nonce = transaction_msg.skill_callback_info.get("tx_nonce", None)
-                # tx_signature = match_accept.info.get("tx_signature", None)
-                # assert (
-                #     tx_nonce is not None and tx_signature is not None
-                # ), "tx_nonce or tx_signature not available"
-                # transaction_msg = contract.get_atomic_swap_batch_transaction_msg(
-                #     from_address=self.context.agent_address,
-                #     to_address=match_accept.counterparty,
-                #     token_ids=[
-                #         int(key)
-                #         for key in transaction_msg.terms.quantities_by_good_id.keys()
-                #     ]
-                #     + [
-                #         int(key)
-                #         for key in transaction_msg.terms.amount_by_currency_id.keys()
-                #     ],
-                #     from_supplies=[
-                #         -quantity if quantity < 0 else 0
-                #         for quantity in transaction_msg.terms.quantities_by_good_id.values()
-                #     ]
-                #     + [
-                #         -value if value < 0 else 0
-                #         for value in transaction_msg.terms.amount_by_currency_id.values()
-                #     ],
-                #     to_supplies=[
-                #         quantity if quantity > 0 else 0
-                #         for quantity in transaction_msg.terms.quantities_by_good_id.values()
-                #     ]
-                #     + [
-                #         value if value > 0 else 0
-                #         for value in transaction_msg.terms.amount_by_currency_id.values()
-                #     ],
-                #     value=0,
-                #     trade_nonce=int(tx_nonce),
-                #     ledger_api=self.context.ledger_apis.get_api(strategy.ledger_id),
-                #     skill_callback_id=self.context.skill_id,
-                #     signature=tx_signature,
-                #     skill_callback_info={
-                #         "dialogue_label": dialogue.dialogue_label.json
-                #     },
-                # )
+                # contract = cast(ERC1155Contract, self.context.contracts.erc1155) # noqa: E800
+                # if not contract.is_deployed: # noqa: E800
+                #     ledger_api = self.context.ledger_apis.get_api(strategy.ledger_id) # noqa: E800
+                #     contract_address = self.context.shared_state.get( # noqa: E800
+                #         "erc1155_contract_address", None # noqa: E800
+                #     ) # noqa: E800
+                #     enforce( # noqa: E800
+                #         contract_address is not None, # noqa: E800
+                #         "ERC1155Contract address not set!" # noqa: E800
+                #     ) # noqa: E800
+                #     contract.set_deployed_instance( # noqa: E800
+                #         ledger_api, cast(str, contract_address), # noqa: E800
+                #     ) # noqa: E800
+                # strategy = cast(Strategy, self.context.strategy) # noqa: E800
+                # tx_nonce = transaction_msg.skill_callback_info.get("tx_nonce", None) # noqa: E800
+                # tx_signature = match_accept.info.get("tx_signature", None) # noqa: E800
+                # enforce( # noqa: E800
+                #     tx_nonce is not None and tx_signature is not None, # noqa: E800
+                #     "tx_nonce or tx_signature not available" # noqa: E800
+                # ) # noqa: E800
+                # transaction_msg = contract.get_atomic_swap_batch_transaction_msg( # noqa: E800
+                #     from_address=self.context.agent_address, # noqa: E800
+                #     to_address=match_accept.counterparty, # noqa: E800
+                #     token_ids=[ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in transaction_msg.terms.quantities_by_good_id.keys() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in transaction_msg.terms.amount_by_currency_id.keys() # noqa: E800
+                #     ], # noqa: E800
+                #     from_supplies=[ # noqa: E800
+                #         -quantity if quantity < 0 else 0 # noqa: E800
+                #         for quantity in transaction_msg.terms.quantities_by_good_id.values() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         -value if value < 0 else 0 # noqa: E800
+                #         for value in transaction_msg.terms.amount_by_currency_id.values() # noqa: E800
+                #     ], # noqa: E800
+                #     to_supplies=[ # noqa: E800
+                #         quantity if quantity > 0 else 0 # noqa: E800
+                #         for quantity in transaction_msg.terms.quantities_by_good_id.values() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         value if value > 0 else 0 # noqa: E800
+                #         for value in transaction_msg.terms.amount_by_currency_id.values() # noqa: E800
+                #     ], # noqa: E800
+                #     value=0, # noqa: E800
+                #     trade_nonce=int(tx_nonce), # noqa: E800
+                #     ledger_api=self.context.ledger_apis.get_api(strategy.ledger_id), # noqa: E800
+                #     skill_callback_id=self.context.skill_id, # noqa: E800
+                #     signature=tx_signature, # noqa: E800
+                #     skill_callback_info={ # noqa: E800
+                #         "dialogue_label": dialogue.dialogue_label.json # noqa: E800
+                #     }, # noqa: E800
+                # ) # noqa: E800
             else:
-                signing_msg.set(
-                    "skill_callback_info",
-                    {
-                        **signing_msg.skill_callback_info,
-                        **{"counterparty_signature": counterparty_signature},
-                    },
-                )
-                signing_dialogues = cast(
-                    SigningDialogues, self.context.signing_dialogues
-                )
-                signing_dialogue = cast(
-                    Optional[SigningDialogue], signing_dialogues.update(signing_msg)
-                )
-                assert (
-                    signing_dialogue is not None
-                ), "Could not construct sigining dialogue."
                 self.context.logger.info(
                     "sending signing_msg={} to decison maker following MATCH_ACCEPT.".format(
                         signing_msg
@@ -601,27 +563,19 @@ class SigningHandler(Handler):
             self.context.logger.warning(
                 "signed message handler only for non-contract case."
             )
-            return None
+            return
         self.context.logger.info("message signed by decision maker.")
-        dialogue_label = DialogueLabel.from_str(
-            cast(str, signing_msg.skill_callback_info.get("dialogue_label"))
-        )
-        fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
-        fipa_dialogue = fipa_dialogues.dialogues[dialogue_label]
+        fipa_dialogue = signing_dialogue.associated_fipa_dialogue
         last_fipa_message = cast(FipaMessage, fipa_dialogue.last_incoming_message)
         if (
             last_fipa_message is not None
             and last_fipa_message.performative == FipaMessage.Performative.ACCEPT
         ):
-            fipa_msg = FipaMessage(
+            fipa_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.MATCH_ACCEPT_W_INFORM,
-                message_id=last_fipa_message.message_id + 1,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=last_fipa_message.message_id,
+                target_message=last_fipa_message,
                 info={"signature": signing_msg.signed_message.body},
             )
-            fipa_msg.counterparty = last_fipa_message.counterparty
-            fipa_dialogue.update(fipa_msg)
             self.context.outbox.put_message(message=fipa_msg)
             self.context.logger.info(
                 "sending match accept to {}.".format(
@@ -633,16 +587,13 @@ class SigningHandler(Handler):
             and last_fipa_message.performative
             == FipaMessage.Performative.MATCH_ACCEPT_W_INFORM
         ):
-            counterparty_signature = cast(
-                str, signing_msg.skill_callback_info.get("counterparty_signature")
-            )
+            counterparty_signature = signing_dialogue.counterparty_signature
             if counterparty_signature is not None:
                 last_signing_msg = cast(
                     Optional[SigningMessage], signing_dialogue.last_outgoing_message
                 )
-                assert (
-                    last_signing_msg is not None
-                ), "Could not recover last signing message."
+                if last_signing_msg is None:
+                    raise ValueError("Could not recover last signing message.")
                 tx_id = last_signing_msg.terms.sender_hash
                 if "transactions" not in self.context.shared_state.keys():
                     self.context.shared_state["transactions"] = {}
@@ -661,7 +612,7 @@ class SigningHandler(Handler):
                 "last message should be of performative accept or match accept."
             )
 
-    def _handle_signed_transaction(
+    def _handle_signed_transaction(  # pylint: disable=unused-argument
         self, signing_msg: SigningMessage, signing_dialogue: SigningDialogue
     ) -> None:
         """
@@ -676,13 +627,9 @@ class SigningHandler(Handler):
             self.context.logger.warning(
                 "signed transaction handler only for contract case."
             )
-            return None
+            return
         self.context.logger.info("transaction signed by decision maker.")
-        dialogue_label = DialogueLabel.from_str(
-            cast(str, signing_msg.skill_callback_info.get("dialogue_label"))
-        )
-        fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
-        fipa_dialogue = fipa_dialogues.dialogues[dialogue_label]
+        fipa_dialogue = signing_dialogue.associated_fipa_dialogue
         last_fipa_message = cast(FipaMessage, fipa_dialogue.last_incoming_message)
         if (
             last_fipa_message is not None
@@ -693,18 +640,14 @@ class SigningHandler(Handler):
                     fipa_dialogue.dialogue_label.dialogue_opponent_addr[-5:],
                 )
             )
-            fipa_msg = FipaMessage(
+            fipa_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.MATCH_ACCEPT_W_INFORM,
-                message_id=last_fipa_message.message_id + 1,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=last_fipa_message.message_id,
+                target_message=last_fipa_message,
                 info={
                     "tx_signature": signing_msg.signed_transaction,
                     "tx_id": signing_msg.dialogue_reference[0],
                 },
             )
-            fipa_msg.counterparty = fipa_dialogue.dialogue_label.dialogue_opponent_addr
-            fipa_dialogue.update(fipa_msg)
             self.context.outbox.put_message(message=fipa_msg)
         elif (
             last_fipa_message is not None
@@ -716,8 +659,8 @@ class SigningHandler(Handler):
             tx_digest = self.context.ledger_apis.get_api(
                 strategy.ledger_id
             ).send_signed_transaction(tx_signed=tx_signed)
-            # TODO; handle case when no tx_digest returned and remove loop
-            assert tx_digest is not None, "Error when submitting tx."
+            if tx_digest is None:
+                raise ValueError("Error when submitting tx.")
             self.context.logger.info("tx_digest={}.".format(tx_digest))
             count = 0
             while (
@@ -744,18 +687,18 @@ class SigningHandler(Handler):
                         tx_digest
                     )
                 )
-                # contract = cast(ERC1155Contract, self.context.contracts.erc1155)
-                # result = contract.get_balances(
-                #     address=self.context.agent_address,
-                #     token_ids=[
-                #         int(key)
-                #         for key in tx_message.terms.quantities_by_good_id.keys()
-                #     ]
-                #     + [
-                #         int(key)
-                #         for key in tx_message.terms.amount_by_currency_id.keys()
-                #     ],
-                # )
+                # contract = cast(ERC1155Contract, self.context.contracts.erc1155) # noqa: E800
+                # result = contract.get_balances( # noqa: E800
+                #     address=self.context.agent_address, # noqa: E800
+                #     token_ids=[ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in tx_message.terms.quantities_by_good_id.keys() # noqa: E800
+                #     ] # noqa: E800
+                #     + [ # noqa: E800
+                #         int(key) # noqa: E800
+                #         for key in tx_message.terms.amount_by_currency_id.keys() # noqa: E800
+                #     ], # noqa: E800
+                # ) # noqa: E800
                 result = 0
                 self.context.logger.info("current balances: {}".format(result))
         else:
@@ -869,7 +812,8 @@ class OefSearchHandler(Handler):
         """
         self.context.logger.warning(
             "received OEF Search error: dialogue_reference={}, oef_error_operation={}".format(
-                oef_search_msg.dialogue_reference, oef_search_msg.oef_error_operation,
+                oef_search_dialogue.dialogue_label.dialogue_reference,
+                oef_search_msg.oef_error_operation,
             )
         )
 
@@ -919,13 +863,11 @@ class OefSearchHandler(Handler):
                 self.context.logger.info(
                     "sending CFP to agent={}".format(opponent_addr[-5:])
                 )
-                fipa_msg = FipaMessage(
-                    dialogue_reference=fipa_dialogues.new_self_initiated_dialogue_reference(),
+                fipa_msg, _ = fipa_dialogues.create(
+                    counterparty=opponent_addr,
                     performative=FipaMessage.Performative.CFP,
                     query=query,
                 )
-                fipa_msg.counterparty = opponent_addr
-                fipa_dialogues.update(fipa_msg)
                 self.context.outbox.put_message(message=fipa_msg)
         else:
             self.context.logger.info(
