@@ -43,11 +43,17 @@ from aea.configurations.base import (
     PublicId,
 )
 from aea.configurations.constants import DEFAULT_CONNECTION
-from aea.crypto.helpers import FETCHAI_PRIVATE_KEY_FILE
 from aea.exceptions import AEAPackageLoadingError
 
 from tests.common.pexpect_popen import PexpectWrapper
-from tests.conftest import AUTHOR, CLI_LOG_OPTION, CliRunner, MAX_FLAKY_RERUNS, ROOT_DIR
+from tests.conftest import (
+    AUTHOR,
+    CLI_LOG_OPTION,
+    CliRunner,
+    FETCHAI_PRIVATE_KEY_FILE,
+    MAX_FLAKY_RERUNS,
+    ROOT_DIR,
+)
 
 
 @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)
@@ -73,7 +79,7 @@ def test_run():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
 
@@ -84,7 +90,7 @@ def test_run():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.7.0",
+            "fetchai/http_client:0.8.0",
         ],
     )
     assert result.exit_code == 0
@@ -165,9 +171,9 @@ def test_run_with_default_connection():
 @pytest.mark.parametrize(
     argnames=["connection_ids"],
     argvalues=[
-        ["fetchai/http_client:0.7.0,{}".format(str(DEFAULT_CONNECTION))],
-        ["'fetchai/http_client:0.7.0, {}'".format(str(DEFAULT_CONNECTION))],
-        ["fetchai/http_client:0.7.0,,{},".format(str(DEFAULT_CONNECTION))],
+        ["fetchai/http_client:0.8.0,{}".format(str(DEFAULT_CONNECTION))],
+        ["'fetchai/http_client:0.8.0, {}'".format(str(DEFAULT_CONNECTION))],
+        ["fetchai/http_client:0.8.0,,{},".format(str(DEFAULT_CONNECTION))],
     ],
 )
 def test_run_multiple_connections(connection_ids):
@@ -192,7 +198,7 @@ def test_run_multiple_connections(connection_ids):
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
 
@@ -248,7 +254,7 @@ def test_run_unknown_private_key():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -258,7 +264,7 @@ def test_run_unknown_private_key():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.7.0",
+            "fetchai/http_client:0.8.0",
         ],
     )
     assert result.exit_code == 0
@@ -271,7 +277,7 @@ def test_run_unknown_private_key():
 
     find_text = "private_key_paths: {}"
     replace_text = """private_key_paths:
-        fetchai_not: fet_private_key.txt"""
+        fetchai_not: fetchai_private_key.txt"""
 
     whole_file = whole_file.replace(find_text, replace_text)
 
@@ -287,11 +293,11 @@ def test_run_unknown_private_key():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.8.0"],
         standalone_mode=False,
     )
 
-    s = "Item not registered with id 'fetchai_not'."
+    s = "Unsupported identifier `fetchai_not` in private key paths. Supported identifiers: ['cosmos', 'ethereum', 'fetchai']."
     assert result.exception.message == s
 
     os.chdir(cwd)
@@ -323,7 +329,7 @@ def test_run_fet_private_key_config():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
 
@@ -347,7 +353,7 @@ def test_run_fet_private_key_config():
 
     error_msg = ""
     try:
-        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"])
+        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.8.0"])
     except SystemExit as e:
         error_msg = str(e)
 
@@ -382,7 +388,7 @@ def test_run_ethereum_private_key_config():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
 
@@ -406,7 +412,7 @@ def test_run_ethereum_private_key_config():
 
     error_msg = ""
     try:
-        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"])
+        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.8.0"])
     except SystemExit as e:
         error_msg = str(e)
 
@@ -444,7 +450,7 @@ def test_run_with_install_deps():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -454,7 +460,7 @@ def test_run_with_install_deps():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.7.0",
+            "fetchai/http_client:0.8.0",
         ],
     )
     assert result.exit_code == 0
@@ -470,7 +476,7 @@ def test_run_with_install_deps():
                 "run",
                 "--install-deps",
                 "--connections",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
             env=os.environ,
             maxread=10000,
@@ -516,7 +522,7 @@ def test_run_with_install_deps_and_requirement_file():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.8.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -526,7 +532,7 @@ def test_run_with_install_deps_and_requirement_file():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.7.0",
+            "fetchai/http_client:0.8.0",
         ],
     )
     assert result.exit_code == 0
@@ -546,7 +552,7 @@ def test_run_with_install_deps_and_requirement_file():
                 "run",
                 "--install-deps",
                 "--connections",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
             env=os.environ,
             maxread=10000,
@@ -604,7 +610,7 @@ class TestRunFailsWhenExceptionOccursInSkill:
                 "add",
                 "--local",
                 "connection",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
             standalone_mode=False,
         )
@@ -621,7 +627,7 @@ class TestRunFailsWhenExceptionOccursInSkill:
 
         try:
             cli.main(
-                [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"]
+                [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.8.0"]
             )
         except SystemExit as e:
             cls.exit_code = e.code
@@ -696,6 +702,59 @@ class TestRunFailsWhenConfigurationFileNotFound:
             pass
 
 
+class TestRunFailsWhenConfigurationFileIsEmpty:
+    """Test that the command 'aea run' fails when the agent configuration file is empty."""
+
+    @classmethod
+    def setup_class(cls):
+        """Set the test up."""
+        cls.runner = CliRunner()
+        cls.agent_name = "myagent"
+        cls.cwd = os.getcwd()
+        cls.t = tempfile.mkdtemp()
+        # copy the 'packages' directory in the parent of the agent folder.
+        shutil.copytree(Path(ROOT_DIR, "packages"), Path(cls.t, "packages"))
+
+        os.chdir(cls.t)
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
+        )
+        assert result.exit_code == 0
+
+        result = cls.runner.invoke(
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", cls.agent_name],
+            standalone_mode=False,
+        )
+        assert result.exit_code == 0
+
+        Path(cls.t, cls.agent_name, DEFAULT_AEA_CONFIG_FILE).write_text("")
+
+        os.chdir(Path(cls.t, cls.agent_name))
+
+        cls.result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "run"], standalone_mode=False
+        )
+
+    def test_exit_code_equal_to_1(self):
+        """Assert that the exit code is equal to 1 (i.e. catchall for general errors)."""
+        assert self.result.exit_code == 1
+
+    def test_log_error_message(self):
+        """Test that the log error message is fixed."""
+        s = "Agent configuration file was empty."
+        assert self.result.exception.message == s
+
+    @classmethod
+    def teardown_class(cls):
+        """Tear the test down."""
+        os.chdir(cls.cwd)
+        try:
+            shutil.rmtree(cls.t)
+        except (OSError, IOError):
+            pass
+
+
 class TestRunFailsWhenConfigurationFileInvalid:
     """Test that the command 'aea run' fails when the agent configuration file is invalid."""
 
@@ -722,7 +781,9 @@ class TestRunFailsWhenConfigurationFileInvalid:
         )
         assert result.exit_code == 0
 
-        Path(cls.t, cls.agent_name, DEFAULT_AEA_CONFIG_FILE).write_text("")
+        Path(cls.t, cls.agent_name, DEFAULT_AEA_CONFIG_FILE).write_text(
+            "invalid_attribute: 'foo'\n"
+        )
 
         os.chdir(Path(cls.t, cls.agent_name))
 
@@ -816,7 +877,7 @@ class TestRunFailsWhenConnectionConfigFileNotFound:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = PublicId.from_str("fetchai/http_client:0.7.0")
+        cls.connection_id = PublicId.from_str("fetchai/http_client:0.8.0")
         cls.connection_name = cls.connection_id.name
         cls.connection_author = cls.connection_id.author
         cls.cwd = os.getcwd()
@@ -850,7 +911,7 @@ class TestRunFailsWhenConnectionConfigFileNotFound:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
         )
         assert result.exit_code == 0
@@ -909,7 +970,7 @@ class TestRunFailsWhenConnectionNotComplete:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = PublicId.from_str("fetchai/http_client:0.7.0")
+        cls.connection_id = PublicId.from_str("fetchai/http_client:0.8.0")
         cls.connection_author = cls.connection_id.author
         cls.connection_name = cls.connection_id.name
         cls.cwd = os.getcwd()
@@ -943,7 +1004,7 @@ class TestRunFailsWhenConnectionNotComplete:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
         )
         assert result.exit_code == 0
@@ -1001,7 +1062,7 @@ class TestRunFailsWhenConnectionClassNotPresent:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = "fetchai/http_client:0.7.0"
+        cls.connection_id = "fetchai/http_client:0.8.0"
         cls.connection_name = "http_client"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
@@ -1034,7 +1095,7 @@ class TestRunFailsWhenConnectionClassNotPresent:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.7.0",
+                "fetchai/http_client:0.8.0",
             ],
         )
         assert result.exit_code == 0
@@ -1188,7 +1249,7 @@ class TestRunFailsWhenProtocolNotComplete:
 
         result = cls.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "--local", "protocol", "fetchai/fipa:0.5.0"],
+            [*CLI_LOG_OPTION, "add", "--local", "protocol", "fetchai/fipa:0.6.0"],
             standalone_mode=False,
         )
         assert result.exit_code == 0
