@@ -27,8 +27,6 @@ import tempfile
 import unittest.mock
 from pathlib import Path
 
-from click.testing import CliRunner
-
 import jsonschema
 from jsonschema import Draft4Validator, ValidationError
 
@@ -43,6 +41,7 @@ from tests.conftest import (
     AUTHOR,
     CLI_LOG_OPTION,
     CONFIGURATION_SCHEMA_DIR,
+    CliRunner,
     SKILL_CONFIGURATION_SCHEMA,
 )
 
