@@ -28,16 +28,18 @@ import pytest
 import web3
 
 from aea.configurations.base import (
-    ComponentConfiguration,
     ComponentType,
     ContractConfig,
 )
+from aea.configurations.loader import load_component_configuration
 from aea.contracts import contract_registry
 from aea.contracts.base import Contract
 from aea.contracts.scaffold.contract import MyScaffoldContract
+from aea.crypto.ethereum import DEFAULT_ADDRESS as ETHEREUM_DEFAULT_ADDRESS
+from aea.crypto.fetchai import DEFAULT_ADDRESS as FETCHAI_DEFAULT_ADDRESS
 from aea.crypto.registries import crypto_registry, ledger_apis_registry
 
-from tests.conftest import COSMOS, ETHEREUM, ROOT_DIR
+from tests.conftest import ETHEREUM, FETCHAI, ROOT_DIR
 
 
 def test_from_dir():
@@ -46,14 +48,15 @@ def test_from_dir():
         os.path.join(ROOT_DIR, "tests", "data", "dummy_contract")
     )
     assert contract is not None
-    assert contract.contract_interface is None
+    assert contract.contract_interface is not None
+    assert isinstance(contract.contract_interface, dict)
 
 
 def test_from_config_and_registration():
     """Tests the from config method and contract registry registration."""
 
     directory = Path(ROOT_DIR, "tests", "data", "dummy_contract")
-    configuration = ComponentConfiguration.load(ComponentType.CONTRACT, directory)
+    configuration = load_component_configuration(ComponentType.CONTRACT, directory)
     configuration._directory = directory
     configuration = cast(ContractConfig, configuration)
 
@@ -62,21 +65,13 @@ def test_from_config_and_registration():
 
     contract = Contract.from_config(configuration)
     assert contract is not None
-    assert contract.contract_interface is None
+    assert contract.contract_interface is not None
+    assert isinstance(contract.contract_interface, dict)
     assert contract.configuration == configuration
     assert contract.id == configuration.public_id
 
-    contract_registry.register(
-        id_=str(configuration.public_id),
-        entry_point=f"{configuration.prefix_import_path}.contract:{configuration.class_name}",
-        class_kwargs={"contract_interface": configuration.contract_interfaces},
-        contract_config=configuration,
-    )
-
-    contract = contract_registry.make(str(configuration.public_id))
-    assert contract is not None
-    assert contract.configuration == configuration
-    assert contract.contract_interface is not None
+    # the contract is registered as side-effect
+    assert str(contract.public_id) in contract_registry.specs
 
 
 def test_non_implemented_class_methods():
@@ -94,34 +89,22 @@ def test_non_implemented_class_methods():
 @pytest.fixture()
 def dummy_contract(request):
     directory = Path(ROOT_DIR, "tests", "data", "dummy_contract")
-    configuration = ComponentConfiguration.load(ComponentType.CONTRACT, directory)
+    configuration = load_component_configuration(ComponentType.CONTRACT, directory)
     configuration._directory = directory
     configuration = cast(ContractConfig, configuration)
 
     if str(configuration.public_id) in contract_registry.specs:
         contract_registry.specs.pop(str(configuration.public_id))
 
-    # load into sys modules
-    Contract.from_config(configuration)
-
-    # load into registry
-    contract_registry.register(
-        id_=str(configuration.public_id),
-        entry_point=f"{configuration.prefix_import_path}.contract:{configuration.class_name}",
-        class_kwargs={"contract_interface": configuration.contract_interfaces},
-        contract_config=configuration,
-    )
-    contract = contract_registry.make(str(configuration.public_id))
+    # load into sys modules and register into contract registry
+    contract = Contract.from_config(configuration)
     yield contract
     contract_registry.specs.pop(str(configuration.public_id))
 
 
 def test_get_instance_no_address_ethereum(dummy_contract):
     """Tests get instance method with no address for ethereum."""
-    ledger_api = ledger_apis_registry.make(
-        ETHEREUM,
-        address="https://ropsten.infura.io/v3/f00f7b3ba0e848ddbdc8941c527447fe",
-    )
+    ledger_api = ledger_apis_registry.make(ETHEREUM, address=ETHEREUM_DEFAULT_ADDRESS,)
     instance = dummy_contract.get_instance(ledger_api)
     assert type(instance) == web3._utils.datatypes.PropertyCheckingFactory
 
@@ -129,10 +112,7 @@ def test_get_instance_no_address_ethereum(dummy_contract):
 def test_get_deploy_transaction_ethereum(dummy_contract):
     """Tests the deploy transaction classmethod for ethereum."""
     ethereum_crypto = crypto_registry.make(ETHEREUM)
-    ledger_api = ledger_apis_registry.make(
-        ETHEREUM,
-        address="https://ropsten.infura.io/v3/f00f7b3ba0e848ddbdc8941c527447fe",
-    )
+    ledger_api = ledger_apis_registry.make(ETHEREUM, address=ETHEREUM_DEFAULT_ADDRESS,)
     deploy_tx = dummy_contract.get_deploy_transaction(
         ledger_api, ethereum_crypto.address
     )
@@ -144,21 +124,19 @@ def test_get_deploy_transaction_ethereum(dummy_contract):
 
 
 def test_get_instance_no_address_cosmwasm(dummy_contract):
-    """Tests get instance method with no address for cosmos."""
-    ledger_api = ledger_apis_registry.make(
-        COSMOS, address="https://rest-agent-land.prod.fetch-ai.com:443",
-    )
+    """Tests get instance method with no address for fetchai."""
+    ledger_api = ledger_apis_registry.make(FETCHAI, address=FETCHAI_DEFAULT_ADDRESS,)
     instance = dummy_contract.get_instance(ledger_api)
     assert instance is None
 
 
 def test_get_deploy_transaction_cosmwasm(dummy_contract):
-    """Tests the deploy transaction classmethod for cosmos."""
-    cosmos_crypto = crypto_registry.make(COSMOS)
-    ledger_api = ledger_apis_registry.make(
-        COSMOS, address="https://rest-agent-land.prod.fetch-ai.com:443",
+    """Tests the deploy transaction classmethod for fetchai."""
+    fetchai_crypto = crypto_registry.make(FETCHAI)
+    ledger_api = ledger_apis_registry.make(FETCHAI, address=FETCHAI_DEFAULT_ADDRESS,)
+    deploy_tx = dummy_contract.get_deploy_transaction(
+        ledger_api, fetchai_crypto.address
     )
-    deploy_tx = dummy_contract.get_deploy_transaction(ledger_api, cosmos_crypto.address)
     assert deploy_tx is not None and len(deploy_tx) == 6
     assert all(
         key in ["account_number", "chain_id", "fee", "memo", "msgs", "sequence"]
@@ -168,4 +146,11 @@ def test_get_deploy_transaction_cosmwasm(dummy_contract):
 
 def test_scaffold():
     """Test the scaffold contract can be loaded/instantiated."""
-    MyScaffoldContract("config")
+    scaffold = MyScaffoldContract("config")
+    kwargs = {"key": "value"}
+    with pytest.raises(NotImplementedError):
+        scaffold.get_raw_transaction("ledger_api", "contract_address", **kwargs)
+    with pytest.raises(NotImplementedError):
+        scaffold.get_raw_message("ledger_api", "contract_address", **kwargs)
+    with pytest.raises(NotImplementedError):
+        scaffold.get_state("ledger_api", "contract_address", **kwargs)
