@@ -21,11 +21,9 @@
 
 import logging
 import os
-import shutil
-import tempfile
 from unittest.mock import patch
 
-import pytest
+from aea.test_tools.test_cases import BaseAEATestCase
 
 from .decision_maker_transaction import (
     logger,
@@ -40,7 +38,7 @@ PY_FILE = "test_docs/test_decision_maker_transaction/decision_maker_transaction.
 test_logger = logging.getLogger(__name__)
 
 
-class TestDecisionMakerTransaction:
+class TestDecisionMakerTransaction(BaseAEATestCase):
     """This class contains the tests for the code-blocks in the agent-vs-aea.md file."""
 
     @classmethod
@@ -55,14 +53,12 @@ class TestDecisionMakerTransaction:
     @classmethod
     def setup_class(cls):
         """Setup the test class."""
+        BaseAEATestCase.setup_class()
         cls._patch_logger()
-        cls.path = os.path.join(ROOT_DIR, MD_FILE)
-        cls.code_blocks = extract_code_blocks(filepath=cls.path, filter="python")
-        path = os.path.join(CUR_PATH, PY_FILE)
-        cls.python_file = extract_python_code(path)
-        cls.cwd = os.getcwd()
-        cls.t = tempfile.mkdtemp()
-        os.chdir(cls.t)
+        doc_path = os.path.join(ROOT_DIR, MD_FILE)
+        cls.code_blocks = extract_code_blocks(filepath=doc_path, filter="python")
+        test_code_path = os.path.join(CUR_PATH, PY_FILE)
+        cls.python_file = extract_python_code(test_code_path)
 
     def test_read_md_file(self):
         """Test the last code block, that is the full listing of the demo from the Markdown."""
@@ -77,11 +73,8 @@ class TestDecisionMakerTransaction:
                 blocks in self.python_file
             ), "Code-block doesn't exist in the python file."
 
-    def test_run_end_to_end(self, pytestconfig):
+    def test_run_end_to_end(self):
         """Run the transaction from the file."""
-        if pytestconfig.getoption("ci"):
-            pytest.skip("Skipping the test since it doesn't work in CI.")
-
         try:
             run()
         except RuntimeError:
@@ -89,9 +82,5 @@ class TestDecisionMakerTransaction:
 
     @classmethod
     def teardown_class(cls):
+        BaseAEATestCase.teardown_class()
         cls._unpatch_logger()
-        os.chdir(cls.cwd)
-        try:
-            shutil.rmtree(cls.t)
-        except (OSError, IOError):
-            pass
