@@ -17,37 +17,42 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This module contains the tests for the FIPA protocol."""
+"""This module contains the tests of the fipa protocol package."""
 
 import logging
+import sys
 from typing import Any, Optional, Type
 from unittest import mock
 
 import pytest
 
 from aea.common import Address
+from aea.exceptions import AEAEnforceError
 from aea.helpers.search.models import Constraint, ConstraintType, Description, Query
 from aea.mail.base import Envelope
 from aea.protocols.base import Message
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 from aea.protocols.dialogue.base import DialogueLabel
 
+import packages
 from packages.fetchai.protocols.fipa.dialogues import FipaDialogue, FipaDialogues
 from packages.fetchai.protocols.fipa.message import FipaMessage
+from packages.fetchai.protocols.fipa.message import logger as fipa_message_logger
+
+from tests.conftest import ROOT_DIR
 
 logger = logging.getLogger(__name__)
+sys.path.append(ROOT_DIR)
 
 
-def test_fipa_cfp_serialization():
+def test_cfp_serialization():
     """Test that the serialization for the 'fipa' protocol works."""
-    query = Query([Constraint("something", ConstraintType(">", 1))])
-
     msg = FipaMessage(
         message_id=1,
         dialogue_reference=(str(0), ""),
         target=0,
         performative=FipaMessage.Performative.CFP,
-        query=query,
+        query=Query([Constraint("something", ConstraintType(">", 1))]),
     )
     msg.to = "receiver"
     envelope = Envelope(
@@ -69,45 +74,14 @@ def test_fipa_cfp_serialization():
     assert expected_msg == actual_msg
 
 
-def test_fipa_cfp_serialization_bytes():
-    """Test that the serialization - deserialization for the 'fipa' protocol works."""
-    query = Query([Constraint("something", ConstraintType(">", 1))])
-    msg = FipaMessage(
-        message_id=1,
-        dialogue_reference=(str(0), ""),
-        target=0,
-        performative=FipaMessage.Performative.CFP,
-        query=query,
-    )
-    msg.to = "receiver"
-    envelope = Envelope(
-        to=msg.to, sender="sender", protocol_id=FipaMessage.protocol_id, message=msg,
-    )
-    envelope_bytes = envelope.encode()
-
-    actual_envelope = Envelope.decode(envelope_bytes)
-    expected_envelope = envelope
-    assert expected_envelope.to == actual_envelope.to
-    assert expected_envelope.sender == actual_envelope.sender
-    assert expected_envelope.protocol_id == actual_envelope.protocol_id
-    assert expected_envelope.message != actual_envelope.message
-
-    actual_msg = FipaMessage.serializer.decode(actual_envelope.message)
-    actual_msg.to = actual_envelope.to
-    actual_msg.sender = actual_envelope.sender
-    expected_msg = msg
-    assert expected_msg == actual_msg
-
-
-def test_fipa_propose_serialization():
+def test_propose_serialization():
     """Test that the serialization for the 'fipa' protocol works."""
-    proposal = Description({"foo1": 1, "bar1": 2})
     msg = FipaMessage(
         message_id=1,
         dialogue_reference=(str(0), ""),
         target=0,
         performative=FipaMessage.Performative.PROPOSE,
-        proposal=proposal,
+        proposal=Description({"foo1": 1, "bar1": 2}),
     )
     msg.to = "receiver"
     envelope = Envelope(
@@ -129,7 +103,7 @@ def test_fipa_propose_serialization():
     assert expected_msg == actual_msg
 
 
-def test_fipa_accept_serialization():
+def test_accept_serialization():
     """Test that the serialization for the 'fipa' protocol works."""
     msg = FipaMessage(
         message_id=1,
@@ -157,7 +131,35 @@ def test_fipa_accept_serialization():
     assert expected_msg == actual_msg
 
 
-def test_performative_match_accept():
+def test_decline_serialization():
+    """Test that the serialization for the 'fipa' protocol works."""
+    msg = FipaMessage(
+        message_id=1,
+        dialogue_reference=(str(0), ""),
+        target=0,
+        performative=FipaMessage.Performative.DECLINE,
+    )
+    msg.to = "receiver"
+    envelope = Envelope(
+        to=msg.to, sender="sender", protocol_id=FipaMessage.protocol_id, message=msg,
+    )
+    envelope_bytes = envelope.encode()
+
+    actual_envelope = Envelope.decode(envelope_bytes)
+    expected_envelope = envelope
+    assert expected_envelope.to == actual_envelope.to
+    assert expected_envelope.sender == actual_envelope.sender
+    assert expected_envelope.protocol_id == actual_envelope.protocol_id
+    assert expected_envelope.message != actual_envelope.message
+
+    actual_msg = FipaMessage.serializer.decode(actual_envelope.message)
+    actual_msg.to = actual_envelope.to
+    actual_msg.sender = actual_envelope.sender
+    expected_msg = msg
+    assert expected_msg == actual_msg
+
+
+def test_match_accept_serialization():
     """Test the serialization - deserialization of the match_accept performative."""
     msg = FipaMessage(
         message_id=1,
@@ -185,7 +187,7 @@ def test_performative_match_accept():
     assert expected_msg == actual_msg
 
 
-def test_performative_accept_with_inform():
+def test_accept_with_inform_serialization():
     """Test the serialization - deserialization of the accept_with_address performative."""
     msg = FipaMessage(
         message_id=1,
@@ -214,7 +216,7 @@ def test_performative_accept_with_inform():
     assert expected_msg == actual_msg
 
 
-def test_performative_match_accept_with_inform():
+def test_match_accept_with_inform_serialization():
     """Test the serialization - deserialization of the match_accept_with_address performative."""
     msg = FipaMessage(
         message_id=1,
@@ -243,7 +245,7 @@ def test_performative_match_accept_with_inform():
     assert expected_msg == actual_msg
 
 
-def test_performative_inform():
+def test_inform_serialization():
     """Test the serialization-deserialization of the inform performative."""
     msg = FipaMessage(
         message_id=1,
@@ -298,28 +300,18 @@ def test_performative_string_value():
     ), "The str value must be inform"
 
 
-def test_fipa_encoding_unknown_performative():
+def test_encoding_unknown_performative():
     """Test that we raise an exception when the performative is unknown during encoding."""
-    msg = FipaMessage(
-        message_id=1,
-        dialogue_reference=(str(0), ""),
-        target=0,
-        performative=FipaMessage.Performative.ACCEPT,
-    )
+    msg = FipaMessage(performative=FipaMessage.Performative.ACCEPT,)
 
     with pytest.raises(ValueError, match="Performative not valid:"):
         with mock.patch.object(FipaMessage.Performative, "__eq__", return_value=False):
             FipaMessage.serializer.encode(msg)
 
 
-def test_fipa_decoding_unknown_performative():
+def test_decoding_unknown_performative():
     """Test that we raise an exception when the performative is unknown during decoding."""
-    msg = FipaMessage(
-        message_id=1,
-        dialogue_reference=(str(0), ""),
-        target=0,
-        performative=FipaMessage.Performative.ACCEPT,
-    )
+    msg = FipaMessage(performative=FipaMessage.Performative.ACCEPT,)
 
     encoded_msg = FipaMessage.serializer.encode(msg)
     with pytest.raises(ValueError, match="Performative not valid:"):
@@ -327,8 +319,26 @@ def test_fipa_decoding_unknown_performative():
             FipaMessage.serializer.decode(encoded_msg)
 
 
+@mock.patch.object(
+    packages.fetchai.protocols.fipa.message,
+    "enforce",
+    side_effect=AEAEnforceError("some error"),
+)
+def test_incorrect_message(mocked_enforce):
+    """Test that we raise an exception when the fipa message is incorrect."""
+    with mock.patch.object(fipa_message_logger, "error") as mock_logger:
+        FipaMessage(
+            message_id=1,
+            dialogue_reference=(str(0), ""),
+            target=0,
+            performative=FipaMessage.Performative.ACCEPT,
+        )
+
+        mock_logger.assert_any_call("some error")
+
+
 class TestDialogues:
-    """Tests dialogues model from the packages protocols fipa."""
+    """Tests fipa dialogues."""
 
     @classmethod
     def setup_class(cls):
@@ -517,6 +527,143 @@ class TestDialogues:
             == buyer_dialogue.dialogue_label.dialogue_reference[0]
         ), "Dialogue refernce changed unexpectedly."
 
+    def test_counter_proposing(self):
+        """Test that fipa supports counter proposing."""
+        cfp_msg, buyer_dialogue = self.buyer_dialogues.create(
+            counterparty=self.seller_addr,
+            performative=FipaMessage.Performative.CFP,
+            query=Query([Constraint("something", ConstraintType(">", 1))]),
+        )
+
+        assert len(buyer_dialogue._outgoing_messages) == 1, "No outgoing message."
+        assert len(buyer_dialogue._incoming_messages) == 0, "Some incoming messages."
+        assert (
+            buyer_dialogue.last_outgoing_message == cfp_msg
+        ), "wrong outgoing message in buyer dialogue after sending cfp."
+        assert (
+            buyer_dialogue.dialogue_label.dialogue_reference[0] != ""
+        ), "Dialogue reference incorrect."
+        assert (
+            buyer_dialogue.dialogue_label.dialogue_reference[1] == ""
+        ), "Dialogue reference incorrect."
+        dialogue_reference_left_part = buyer_dialogue.dialogue_label.dialogue_reference[
+            0
+        ]
+
+        # cfp arrives at seller
+
+        seller_dialogue = self.seller_dialogues.update(cfp_msg)
+
+        assert len(seller_dialogue._outgoing_messages) == 0, "Some outgoing message."
+        assert len(seller_dialogue._incoming_messages) == 1, "No incoming messages."
+        assert (
+            seller_dialogue.last_incoming_message == cfp_msg
+        ), "wrong incoming message in seller dialogue after receiving cfp."
+        assert (
+            seller_dialogue.dialogue_label.dialogue_reference[0] != ""
+        ), "Dialogue reference incorrect."
+        assert (
+            seller_dialogue.dialogue_label.dialogue_reference[1] != ""
+        ), "Dialogue reference incorrect."
+
+        # seller creates proposal
+        proposal_msg = seller_dialogue.reply(
+            target_message=cfp_msg,
+            performative=FipaMessage.Performative.PROPOSE,
+            proposal=Description({"foo1": 1, "bar1": 2}),
+        )
+
+        assert len(seller_dialogue._outgoing_messages) == 1, "No outgoing messages."
+        assert len(seller_dialogue._incoming_messages) == 1, "No incoming messages."
+        assert (
+            seller_dialogue.last_outgoing_message == proposal_msg
+        ), "wrong outgoing message in seller dialogue after sending proposal."
+
+        # proposal arrives at buyer
+
+        buyer_dialogue = self.buyer_dialogues.update(proposal_msg)
+
+        assert len(buyer_dialogue._outgoing_messages) == 1, "No outgoing messages."
+        assert len(buyer_dialogue._incoming_messages) == 1, "No incoming messages."
+        assert (
+            buyer_dialogue.last_incoming_message == proposal_msg
+        ), "wrong incoming message in buyer dialogue after receiving proposal."
+        assert (
+            buyer_dialogue.last_incoming_message == proposal_msg
+        ), "Wrong incoming message."
+        assert (
+            buyer_dialogue.dialogue_label.dialogue_reference[0] != ""
+        ), "Dialogue reference incorrect."
+        assert (
+            buyer_dialogue.dialogue_label.dialogue_reference[1] != ""
+        ), "Dialogue reference incorrect."
+        assert (
+            dialogue_reference_left_part
+            == buyer_dialogue.dialogue_label.dialogue_reference[0]
+        ), "Dialogue refernce changed unexpectedly."
+
+        # buyer creates counter proposal 1
+        counter_proposal_msg_1 = buyer_dialogue.reply(
+            target_message=proposal_msg,
+            performative=FipaMessage.Performative.PROPOSE,
+            proposal=Description({"foo1": 3, "bar1": 3}),
+        )
+
+        assert (
+            len(buyer_dialogue._outgoing_messages) == 2
+        ), "incorrect number of outgoing_messages in buyer dialogue after sending counter-proposal 1."
+        assert (
+            len(buyer_dialogue._incoming_messages) == 1
+        ), "incorrect number of incoming_messages in buyer dialogue after sending counter-proposal 1."
+        assert (
+            buyer_dialogue.last_outgoing_message == counter_proposal_msg_1
+        ), "wrong outgoing message in buyer dialogue after sending counter-proposal 1."
+
+        # counter-proposal 1 arrives at seller
+
+        seller_dialogue = self.seller_dialogues.update(counter_proposal_msg_1)
+
+        assert (
+            len(seller_dialogue._outgoing_messages) == 1
+        ), "incorrect number of outgoing_messages in seller dialogue after receiving counter-proposal 1."
+        assert (
+            len(seller_dialogue._incoming_messages) == 2
+        ), "incorrect number of incoming_messages in seller dialogue after receiving counter-proposal 1."
+        assert (
+            seller_dialogue.last_incoming_message == counter_proposal_msg_1
+        ), "wrong incoming message in seller dialogue after receiving counter-proposal 1."
+
+        # seller creates counter-proposal 2
+        counter_proposal_msg_2 = seller_dialogue.reply(
+            target_message=counter_proposal_msg_1,
+            performative=FipaMessage.Performative.PROPOSE,
+            proposal=Description({"foo1": 2, "bar1": 2}),
+        )
+
+        assert (
+            len(seller_dialogue._outgoing_messages) == 2
+        ), "incorrect number of outgoing_messages in seller dialogue after sending counter-proposal 2."
+        assert (
+            len(seller_dialogue._incoming_messages) == 2
+        ), "incorrect number of incoming_messages in seller dialogue after sending counter-proposal 2."
+        assert (
+            seller_dialogue.last_outgoing_message == counter_proposal_msg_2
+        ), "wrong outgoing message in seller dialogue after sending counter-proposal 2."
+
+        # counter-proposal 2 arrives at buyer
+
+        buyer_dialogue = self.buyer_dialogues.update(counter_proposal_msg_2)
+
+        assert (
+            len(buyer_dialogue._outgoing_messages) == 2
+        ), "incorrect number of outgoing_messages in buyer dialogue after receiving counter-proposal 2."
+        assert (
+            len(buyer_dialogue._incoming_messages) == 2
+        ), "incorrect number of incoming_messages in buyer dialogue after receiving counter-proposal 2."
+        assert (
+            buyer_dialogue.last_incoming_message == counter_proposal_msg_2
+        ), "wrong incoming message in buyer dialogue after receiving counter-proposal 2."
+
 
 class BuyerDialogue(FipaDialogue):
     """The dialogue class maintains state of a dialogue and manages it."""
