@@ -22,18 +22,19 @@
 import os
 import shutil
 import tempfile
+from enum import Enum
 from pathlib import Path
-from typing import List, Tuple, Type
-from unittest.mock import MagicMock
+from typing import Callable, List, Tuple, Type
 
 import pytest
 
 from aea import AEA_DIR
 from aea.configurations.constants import DEFAULT_PROTOCOL
-from aea.helpers.dialogue.base import DialogueLabel
+from aea.exceptions import AEAEnforceError
 from aea.mail.base import Envelope
-from aea.protocols.base import JSONSerializer, Message, ProtobufSerializer, Protocol
+from aea.protocols.base import Message, ProtobufSerializer, Protocol
 from aea.protocols.default.dialogues import DefaultDialogue, DefaultDialogues
+from aea.protocols.dialogue.base import Dialogue, DialogueLabel
 from aea.protocols.signing.dialogues import SigningDialogue, SigningDialogues
 from aea.protocols.state_update.dialogues import (
     StateUpdateDialogue,
@@ -43,10 +44,46 @@ from aea.protocols.state_update.dialogues import (
 from tests.conftest import UNKNOWN_PROTOCOL_PUBLIC_ID
 
 
-DIALOGUE_CLASSES: List[Tuple[Type, Type]] = [
-    (DefaultDialogue, DefaultDialogues),
-    (SigningDialogue, SigningDialogues),
-    (StateUpdateDialogue, StateUpdateDialogues),
+def role_from_first_message_dd(
+    message: Message, receiver_address: str
+) -> Dialogue.Role:
+    """Role from first message."""
+    return DefaultDialogue.Role.AGENT
+
+
+def role_from_first_message_sd(
+    message: Message, receiver_address: str
+) -> Dialogue.Role:
+    """Role from first message."""
+    return SigningDialogue.Role.SKILL
+
+
+def role_from_first_message_sud(
+    message: Message, receiver_address: str
+) -> Dialogue.Role:
+    """Role from first message."""
+    return StateUpdateDialogue.Role.SKILL
+
+
+DIALOGUE_CLASSES: List[Tuple[Type, Type, Enum, Callable]] = [
+    (
+        DefaultDialogue,
+        DefaultDialogues,
+        DefaultDialogue.Role.AGENT,
+        role_from_first_message_dd,
+    ),
+    (
+        SigningDialogue,
+        SigningDialogues,
+        SigningDialogue.Role.SKILL,
+        role_from_first_message_sd,
+    ),
+    (
+        StateUpdateDialogue,
+        StateUpdateDialogues,
+        StateUpdateDialogue.Role.SKILL,
+        role_from_first_message_sud,
+    ),
 ]
 
 
@@ -64,9 +101,17 @@ class TestMessageProperties:
             assert self.message.get(key) == value
         assert self.message.get("kwarg") == self.kwarg
         assert not self.message.has_sender
-        assert not self.message.has_counterparty
         assert not self.message.has_to
-        assert not self.message.is_incoming
+        to = "to"
+        sender = "sender"
+        self.message.to = to
+        self.message.sender = sender
+        assert self.message.sender == sender
+        assert self.message.to == to
+        assert (
+            str(self.message)
+            == "Message(sender=sender,to=to,body_1=1,body_2=2,kwarg=1)"
+        )
 
 
 class TestBaseSerializations:
@@ -97,25 +142,6 @@ class TestBaseSerializations:
         actual_msg = self.message
         assert expected_msg == actual_msg
 
-    def test_default_json_serialization(self):
-        """Test that the default JSON serialization works."""
-        message_bytes = JSONSerializer().encode(self.message)
-        envelope = Envelope(
-            to="receiver",
-            sender="sender",
-            protocol_id=UNKNOWN_PROTOCOL_PUBLIC_ID,
-            message=message_bytes,
-        )
-        envelope_bytes = envelope.encode()
-
-        expected_envelope = Envelope.decode(envelope_bytes)
-        actual_envelope = envelope
-        assert expected_envelope == actual_envelope
-
-        expected_msg = JSONSerializer().decode(expected_envelope.message)
-        actual_msg = self.message
-        assert expected_msg == actual_msg
-
     def test_set(self):
         """Test that the set method works."""
         key, value = "temporary_key", "temporary_value"
@@ -123,11 +149,6 @@ class TestBaseSerializations:
         self.message.set(key, value)
         assert self.message.get(key) == value
 
-    def test_unset(self):
-        """Test the unset function of the message."""
-        self.message2.unset("content")
-        assert "content" not in self.message2.body.keys()
-
     def test_body_setter(self):
         """Test the body setter."""
         m_dict = {"Hello": "World"}
@@ -151,6 +172,7 @@ class TestProtocolFromDir:
         assert str(default_protocol.public_id) == str(
             DEFAULT_PROTOCOL
         ), "Protocol not loaded correctly."
+        assert default_protocol.serializer is not None
 
     @classmethod
     def teardown_class(cls):
@@ -178,13 +200,13 @@ class TestMessageAttributes:
     def test_to(self):
         """Test the 'to' attribute getter and setter."""
         message = Message()
-        with pytest.raises(AssertionError, match="To must not be None."):
+        with pytest.raises(ValueError, match="Message's 'To' field must be set."):
             message.to
 
         message.to = "to"
         assert message.to == "to"
 
-        with pytest.raises(AssertionError, match="To already set."):
+        with pytest.raises(AEAEnforceError, match="To already set."):
             message.to = "to"
 
     def test_dialogue_reference(self):
@@ -206,19 +228,14 @@ class TestMessageAttributes:
 @pytest.mark.parametrize("dialogue_classes", DIALOGUE_CLASSES)
 def test_dialogue(dialogue_classes):
     """Test dialogue initialization."""
-    dialogue_class, _ = dialogue_classes
-    dialogue = dialogue_class(DialogueLabel(("x", "y"), "opponent_addr", "starer_addr"))
-    assert dialogue.is_valid(MagicMock())
+    dialogue_class, _, role, _ = dialogue_classes
+    dialogue_class(
+        DialogueLabel(("x", "y"), "opponent_addr", "starer_addr"), "agent_address", role
+    )
 
 
 @pytest.mark.parametrize("dialogues_classes", DIALOGUE_CLASSES)
-def test_default_dialogues(dialogues_classes):
-    """Test default dialogues initialization."""
-    dialogue_class, dialogues_class = dialogues_classes
-    dialogues = dialogues_class("agent_address")
-
-    dialogue = dialogues.create_dialogue(
-        DialogueLabel(("x", "y"), "opponent_addr", "starter_addr"),
-        next(iter(dialogue_class.Role)),
-    )
-    assert isinstance(dialogue, dialogue_class)
+def test_dialogues(dialogues_classes):
+    """Test dialogues initialization."""
+    dialogue_class, dialogues_class, _, role_from_first_message = dialogues_classes
+    dialogues_class("agent_address", role_from_first_message, dialogue_class)
